Class: RocketStackSdk::CreateCronJobRequestSchedule

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateCronJobRequestSchedule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::CreateCronJobRequestSchedule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::CreateCronJobRequestSchedule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'expression')
    self.expression = attributes[:'expression']
  else
    self.expression = nil
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = 'unix5'
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end
end

Instance Attribute Details

#expressionObject

Returns the value of attribute expression.



18
19
20
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 18

def expression
  @expression
end

#formatObject

Returns the value of attribute format.



20
21
22
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 20

def format
  @format
end

#timezoneObject

Returns the value of attribute timezone.



22
23
24
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 22

def timezone
  @timezone
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 47

def self.attribute_map
  {
    :'expression' => :'expression',
    :'format' => :'format',
    :'timezone' => :'timezone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 66

def self.openapi_types
  {
    :'expression' => :'String',
    :'format' => :'String',
    :'timezone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      expression == o.expression &&
      format == o.format &&
      timezone == o.timezone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 182

def hash
  [expression, format, timezone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expression.nil?
    invalid_properties.push('invalid value for "expression", expression cannot be nil.')
  end

  if @expression.to_s.length < 1
    invalid_properties.push('invalid value for "expression", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
138
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_schedule.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expression.nil?
  return false if @expression.to_s.length < 1
  format_validator = EnumAttributeValidator.new('String', ["aws", "unix5"])
  return false unless format_validator.valid?(@format)
  true
end