Class: RocketStackSdk::CreateDownloadUrl200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::CreateDownloadUrl200ResponseData
- Defined in:
- lib/rocket_stack_sdk/models/create_download_url200_response_data.rb
Instance Attribute Summary collapse
-
#download_url ⇒ Object
Returns the value of attribute download_url.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#path ⇒ Object
Returns the value of attribute path.
-
#public_url ⇒ Object
Returns the value of attribute public_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDownloadUrl200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateDownloadUrl200ResponseData
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::CreateDownloadUrl200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::CreateDownloadUrl200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'path') self.path = attributes[:'path'] else self.path = nil end if attributes.key?(:'download_url') self.download_url = attributes[:'download_url'] else self.download_url = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'public_url') self.public_url = attributes[:'public_url'] end end |
Instance Attribute Details
#download_url ⇒ Object
Returns the value of attribute download_url.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 20 def download_url @download_url end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
22 23 24 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 22 def expires_at @expires_at end |
#path ⇒ Object
Returns the value of attribute path.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 18 def path @path end |
#public_url ⇒ Object
Returns the value of attribute public_url.
24 25 26 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 24 def public_url @public_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 27 def self.attribute_map { :'path' => :'path', :'download_url' => :'downloadUrl', :'expires_at' => :'expiresAt', :'public_url' => :'publicUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 61 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 57 def self.openapi_nullable Set.new([ :'expires_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 47 def self.openapi_types { :'path' => :'String', :'download_url' => :'String', :'expires_at' => :'Time', :'public_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && path == o.path && download_url == o.download_url && expires_at == o.expires_at && public_url == o.public_url end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 166 def hash [path, download_url, expires_at, public_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @path.nil? invalid_properties.push('invalid value for "path", path cannot be nil.') end if @download_url.nil? invalid_properties.push('invalid value for "download_url", download_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 124 125 |
# File 'lib/rocket_stack_sdk/models/create_download_url200_response_data.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @path.nil? return false if @download_url.nil? true end |