Class: RocketStackSdk::CreateDownloadUrlRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/create_download_url_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateDownloadUrlRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::CreateDownloadUrlRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::CreateDownloadUrlRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = nil
  end

  if attributes.key?(:'expires_in_seconds')
    self.expires_in_seconds = attributes[:'expires_in_seconds']
  end

  if attributes.key?(:'public')
    self.public = attributes[:'public']
  end
end

Instance Attribute Details

#expires_in_secondsObject

Returns the value of attribute expires_in_seconds.



21
22
23
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 21

def expires_in_seconds
  @expires_in_seconds
end

#pathObject

Object path without leading slash. Segments: letters, digits, dots, underscores, hyphens only.



19
20
21
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 19

def path
  @path
end

#publicObject

Returns the value of attribute public.



23
24
25
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 23

def public
  @public
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



35
36
37
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 35

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



40
41
42
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 40

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 26

def self.attribute_map
  {
    :'path' => :'path',
    :'expires_in_seconds' => :'expiresInSeconds',
    :'public' => :'public'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



54
55
56
57
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 54

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 45

def self.openapi_types
  {
    :'path' => :'String',
    :'expires_in_seconds' => :'Integer',
    :'public' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      path == o.path &&
      expires_in_seconds == o.expires_in_seconds &&
      public == o.public
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 184

def hash
  [path, expires_in_seconds, public].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 92

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @path.nil?
    invalid_properties.push('invalid value for "path", path cannot be nil.')
  end

  if @path.to_s.length > 1024
    invalid_properties.push('invalid value for "path", the character length must be smaller than or equal to 1024.')
  end

  if @path.to_s.length < 1
    invalid_properties.push('invalid value for "path", the character length must be greater than or equal to 1.')
  end

  if !@expires_in_seconds.nil? && @expires_in_seconds > 3600
    invalid_properties.push('invalid value for "expires_in_seconds", must be smaller than or equal to 3600.')
  end

  if !@expires_in_seconds.nil? && @expires_in_seconds < 60
    invalid_properties.push('invalid value for "expires_in_seconds", must be greater than or equal to 60.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



120
121
122
123
124
125
126
127
128
# File 'lib/rocket_stack_sdk/models/create_download_url_request.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @path.nil?
  return false if @path.to_s.length > 1024
  return false if @path.to_s.length < 1
  return false if !@expires_in_seconds.nil? && @expires_in_seconds > 3600
  return false if !@expires_in_seconds.nil? && @expires_in_seconds < 60
  true
end