Class: RocketStackSdk::CreateQueueRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::CreateQueueRequest
- Defined in:
- lib/rocket_stack_sdk/models/create_queue_request.rb
Instance Attribute Summary collapse
-
#delivery_target ⇒ Object
Returns the value of attribute delivery_target.
-
#max_receive_count ⇒ Object
Returns the value of attribute max_receive_count.
-
#name ⇒ Object
Returns the value of attribute name.
-
#retention_seconds ⇒ Object
Returns the value of attribute retention_seconds.
-
#visibility_timeout_seconds ⇒ Object
Returns the value of attribute visibility_timeout_seconds.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateQueueRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateQueueRequest
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::CreateQueueRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::CreateQueueRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'visibility_timeout_seconds') self.visibility_timeout_seconds = attributes[:'visibility_timeout_seconds'] end if attributes.key?(:'retention_seconds') self.retention_seconds = attributes[:'retention_seconds'] end if attributes.key?(:'max_receive_count') self.max_receive_count = attributes[:'max_receive_count'] end if attributes.key?(:'delivery_target') self.delivery_target = attributes[:'delivery_target'] end end |
Instance Attribute Details
#delivery_target ⇒ Object
Returns the value of attribute delivery_target.
26 27 28 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 26 def delivery_target @delivery_target end |
#max_receive_count ⇒ Object
Returns the value of attribute max_receive_count.
24 25 26 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 24 def max_receive_count @max_receive_count end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 18 def name @name end |
#retention_seconds ⇒ Object
Returns the value of attribute retention_seconds.
22 23 24 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 22 def retention_seconds @retention_seconds end |
#visibility_timeout_seconds ⇒ Object
Returns the value of attribute visibility_timeout_seconds.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 20 def visibility_timeout_seconds @visibility_timeout_seconds end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 29 def self.attribute_map { :'name' => :'name', :'visibility_timeout_seconds' => :'visibilityTimeoutSeconds', :'retention_seconds' => :'retentionSeconds', :'max_receive_count' => :'maxReceiveCount', :'delivery_target' => :'deliveryTarget' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 275 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 50 def self.openapi_types { :'name' => :'String', :'visibility_timeout_seconds' => :'Float', :'retention_seconds' => :'Float', :'max_receive_count' => :'Float', :'delivery_target' => :'CreateQueueRequestDeliveryTarget' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && visibility_timeout_seconds == o.visibility_timeout_seconds && retention_seconds == o.retention_seconds && max_receive_count == o.max_receive_count && delivery_target == o.delivery_target end |
#eql?(o) ⇒ Boolean
262 263 264 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 262 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
268 269 270 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 268 def hash [name, visibility_timeout_seconds, retention_seconds, max_receive_count, delivery_target].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 64 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 64.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[a-zA-Z][a-zA-Z0-9-_]*$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds > 43200 invalid_properties.push('invalid value for "visibility_timeout_seconds", must be smaller than or equal to 43200.') end if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds < 0 invalid_properties.push('invalid value for "visibility_timeout_seconds", must be greater than or equal to 0.') end if !@retention_seconds.nil? && @retention_seconds > 1209600 invalid_properties.push('invalid value for "retention_seconds", must be smaller than or equal to 1209600.') end if !@retention_seconds.nil? && @retention_seconds < 60 invalid_properties.push('invalid value for "retention_seconds", must be greater than or equal to 60.') end if !@max_receive_count.nil? && @max_receive_count > 100 invalid_properties.push('invalid value for "max_receive_count", must be smaller than or equal to 100.') end if !@max_receive_count.nil? && @max_receive_count < 1 invalid_properties.push('invalid value for "max_receive_count", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 297 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/rocket_stack_sdk/models/create_queue_request.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 64 return false if @name.to_s.length < 1 return false if @name !~ Regexp.new(/^[a-zA-Z][a-zA-Z0-9-_]*$/) return false if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds > 43200 return false if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds < 0 return false if !@retention_seconds.nil? && @retention_seconds > 1209600 return false if !@retention_seconds.nil? && @retention_seconds < 60 return false if !@max_receive_count.nil? && @max_receive_count > 100 return false if !@max_receive_count.nil? && @max_receive_count < 1 true end |