Class: RocketStackSdk::CreateQueueRequestDeliveryTargetAnyOf
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::CreateQueueRequestDeliveryTargetAnyOf
- Defined in:
- lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#function_id ⇒ Object
Function resource ID.
-
#max_in_flight ⇒ Object
Returns the value of attribute max_in_flight.
-
#max_per_second ⇒ Object
Returns the value of attribute max_per_second.
-
#retryable_status_codes ⇒ Object
HTTP status codes that trigger delivery retries.
-
#timeout_seconds ⇒ Object
Returns the value of attribute timeout_seconds.
-
#type ⇒ Object
Deliver to a RocketStack function.
-
#webhook_headers ⇒ Object
Optional webhook headers (max 10).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateQueueRequestDeliveryTargetAnyOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateQueueRequestDeliveryTargetAnyOf
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::CreateQueueRequestDeliveryTargetAnyOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::CreateQueueRequestDeliveryTargetAnyOf`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'function_id') self.function_id = attributes[:'function_id'] else self.function_id = nil end if attributes.key?(:'webhook_headers') if (value = attributes[:'webhook_headers']).is_a?(Hash) self.webhook_headers = value end end if attributes.key?(:'timeout_seconds') self.timeout_seconds = attributes[:'timeout_seconds'] end if attributes.key?(:'max_in_flight') self.max_in_flight = attributes[:'max_in_flight'] end if attributes.key?(:'max_per_second') self.max_per_second = attributes[:'max_per_second'] end if attributes.key?(:'retryable_status_codes') if (value = attributes[:'retryable_status_codes']).is_a?(Array) self.retryable_status_codes = value end end end |
Instance Attribute Details
#function_id ⇒ Object
Function resource ID. Required when type is function.
22 23 24 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 22 def function_id @function_id end |
#max_in_flight ⇒ Object
Returns the value of attribute max_in_flight.
29 30 31 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 29 def max_in_flight @max_in_flight end |
#max_per_second ⇒ Object
Returns the value of attribute max_per_second.
31 32 33 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 31 def max_per_second @max_per_second end |
#retryable_status_codes ⇒ Object
HTTP status codes that trigger delivery retries.
34 35 36 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 34 def retryable_status_codes @retryable_status_codes end |
#timeout_seconds ⇒ Object
Returns the value of attribute timeout_seconds.
27 28 29 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 27 def timeout_seconds @timeout_seconds end |
#type ⇒ Object
Deliver to a RocketStack function.
19 20 21 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 19 def type @type end |
#webhook_headers ⇒ Object
Optional webhook headers (max 10). Authorization, Cookie, Host, and Content-Length are forbidden.
25 26 27 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 25 def webhook_headers @webhook_headers end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 59 def self.attribute_map { :'type' => :'type', :'function_id' => :'functionId', :'webhook_headers' => :'webhookHeaders', :'timeout_seconds' => :'timeoutSeconds', :'max_in_flight' => :'maxInFlight', :'max_per_second' => :'maxPerSecond', :'retryable_status_codes' => :'retryableStatusCodes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 313 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 82 def self.openapi_types { :'type' => :'String', :'function_id' => :'String', :'webhook_headers' => :'Hash<String, String>', :'timeout_seconds' => :'Float', :'max_in_flight' => :'Float', :'max_per_second' => :'Float', :'retryable_status_codes' => :'Array<Float>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 286 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && function_id == o.function_id && webhook_headers == o.webhook_headers && timeout_seconds == o.timeout_seconds && max_in_flight == o.max_in_flight && max_per_second == o.max_per_second && retryable_status_codes == o.retryable_status_codes end |
#eql?(o) ⇒ Boolean
300 301 302 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 300 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
306 307 308 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 306 def hash [type, function_id, webhook_headers, timeout_seconds, max_in_flight, max_per_second, retryable_status_codes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @function_id.nil? invalid_properties.push('invalid value for "function_id", function_id cannot be nil.') end if !@timeout_seconds.nil? && @timeout_seconds > 30 invalid_properties.push('invalid value for "timeout_seconds", must be smaller than or equal to 30.') end if !@timeout_seconds.nil? && @timeout_seconds < 1 invalid_properties.push('invalid value for "timeout_seconds", must be greater than or equal to 1.') end if !@max_in_flight.nil? && @max_in_flight > 100 invalid_properties.push('invalid value for "max_in_flight", must be smaller than or equal to 100.') end if !@max_in_flight.nil? && @max_in_flight < 1 invalid_properties.push('invalid value for "max_in_flight", must be greater than or equal to 1.') end if !@max_per_second.nil? && @max_per_second > 1000 invalid_properties.push('invalid value for "max_per_second", must be smaller than or equal to 1000.') end if !@max_per_second.nil? && @max_per_second < 1 invalid_properties.push('invalid value for "max_per_second", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/rocket_stack_sdk/models/create_queue_request_delivery_target_any_of.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["function"]) return false unless type_validator.valid?(@type) return false if @function_id.nil? return false if !@timeout_seconds.nil? && @timeout_seconds > 30 return false if !@timeout_seconds.nil? && @timeout_seconds < 1 return false if !@max_in_flight.nil? && @max_in_flight > 100 return false if !@max_in_flight.nil? && @max_in_flight < 1 return false if !@max_per_second.nil? && @max_per_second > 1000 return false if !@max_per_second.nil? && @max_per_second < 1 true end |