Class: RocketStackSdk::CreateScheduleRequest

Inherits:
ApiModelBase show all
Defined in:
lib/rocket_stack_sdk/models/create_schedule_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateScheduleRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::CreateScheduleRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::CreateScheduleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'run_at')
    self.run_at = attributes[:'run_at']
  else
    self.run_at = nil
  end

  if attributes.key?(:'delivery_target')
    self.delivery_target = attributes[:'delivery_target']
  else
    self.delivery_target = nil
  end

  if attributes.key?(:'paused')
    self.paused = attributes[:'paused']
  end

  if attributes.key?(:'payload_template')
    if (value = attributes[:'payload_template']).is_a?(Hash)
      self.payload_template = value
    end
  end
end

Instance Attribute Details

#delivery_targetObject

Returns the value of attribute delivery_target.



22
23
24
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 22

def delivery_target
  @delivery_target
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 18

def name
  @name
end

#pausedObject

Returns the value of attribute paused.



24
25
26
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 24

def paused
  @paused
end

#payload_templateObject

Returns the value of attribute payload_template.



26
27
28
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 26

def payload_template
  @payload_template
end

#run_atObject

Returns the value of attribute run_at.



20
21
22
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 20

def run_at
  @run_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 29

def self.attribute_map
  {
    :'name' => :'name',
    :'run_at' => :'runAt',
    :'delivery_target' => :'deliveryTarget',
    :'paused' => :'paused',
    :'payload_template' => :'payloadTemplate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 50

def self.openapi_types
  {
    :'name' => :'String',
    :'run_at' => :'String',
    :'delivery_target' => :'CreateCronJobRequestDeliveryTarget',
    :'paused' => :'Boolean',
    :'payload_template' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      run_at == o.run_at &&
      delivery_target == o.delivery_target &&
      paused == o.paused &&
      payload_template == o.payload_template
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 220

def hash
  [name, run_at, delivery_target, paused, payload_template].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 64
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 64.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z][a-zA-Z0-9-_]*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @run_at.nil?
    invalid_properties.push('invalid value for "run_at", run_at cannot be nil.')
  end

  if @delivery_target.nil?
    invalid_properties.push('invalid value for "delivery_target", delivery_target cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
153
154
155
# File 'lib/rocket_stack_sdk/models/create_schedule_request.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 64
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[a-zA-Z][a-zA-Z0-9-_]*$/)
  return false if @run_at.nil?
  return false if @delivery_target.nil?
  true
end