Class: RocketStackSdk::CronApi
- Inherits:
-
Object
- Object
- RocketStackSdk::CronApi
- Defined in:
- lib/rocket_stack_sdk/api/cron_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_cron_job(create_cron_job_request, opts = {}) ⇒ CreateCronJob201Response
Create a new cron job Creates a new scheduled cron job with the specified schedule and delivery target.
-
#create_cron_job_with_http_info(create_cron_job_request, opts = {}) ⇒ Array<(CreateCronJob201Response, Integer, Hash)>
Create a new cron job Creates a new scheduled cron job with the specified schedule and delivery target.
-
#delete_cron_job(id, opts = {}) ⇒ DeleteCronJob200Response
Delete a cron job Deletes a cron job and its associated AWS resources.
-
#delete_cron_job_with_http_info(id, opts = {}) ⇒ Array<(DeleteCronJob200Response, Integer, Hash)>
Delete a cron job Deletes a cron job and its associated AWS resources.
-
#get_cron_job(id, opts = {}) ⇒ GetCronJob200Response
Get a cron job by ID Retrieves details of a specific cron job including its schedule and configuration.
-
#get_cron_job_with_http_info(id, opts = {}) ⇒ Array<(GetCronJob200Response, Integer, Hash)>
Get a cron job by ID Retrieves details of a specific cron job including its schedule and configuration.
-
#initialize(api_client = ApiClient.default) ⇒ CronApi
constructor
A new instance of CronApi.
-
#list_cron_invocations(id, opts = {}) ⇒ ListCronInvocations200Response
List cron invocation history Returns a paginated list of delivery attempts and outcomes for a cron job.
-
#list_cron_invocations_with_http_info(id, opts = {}) ⇒ Array<(ListCronInvocations200Response, Integer, Hash)>
List cron invocation history Returns a paginated list of delivery attempts and outcomes for a cron job.
-
#list_cron_jobs(opts = {}) ⇒ ListCronJobs200Response
List cron jobs Returns a paginated list of cron jobs for the tenant.
-
#list_cron_jobs_with_http_info(opts = {}) ⇒ Array<(ListCronJobs200Response, Integer, Hash)>
List cron jobs Returns a paginated list of cron jobs for the tenant.
-
#update_cron_job(id, opts = {}) ⇒ UpdateCronJob200Response
Update a cron job Updates cron job configuration.
-
#update_cron_job_with_http_info(id, opts = {}) ⇒ Array<(UpdateCronJob200Response, Integer, Hash)>
Update a cron job Updates cron job configuration.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_cron_job(create_cron_job_request, opts = {}) ⇒ CreateCronJob201Response
Create a new cron job Creates a new scheduled cron job with the specified schedule and delivery target.
27 28 29 30 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 27 def create_cron_job(create_cron_job_request, opts = {}) data, _status_code, _headers = create_cron_job_with_http_info(create_cron_job_request, opts) data end |
#create_cron_job_with_http_info(create_cron_job_request, opts = {}) ⇒ Array<(CreateCronJob201Response, Integer, Hash)>
Create a new cron job Creates a new scheduled cron job with the specified schedule and delivery target.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 37 def create_cron_job_with_http_info(create_cron_job_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CronApi.create_cron_job ...' end # verify the required parameter 'create_cron_job_request' is set if @api_client.config.client_side_validation && create_cron_job_request.nil? fail ArgumentError, "Missing the required parameter 'create_cron_job_request' when calling CronApi.create_cron_job" end # resource path local_var_path = '/cron' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_cron_job_request) # return_type return_type = opts[:debug_return_type] || 'CreateCronJob201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CronApi.create_cron_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CronApi#create_cron_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_cron_job(id, opts = {}) ⇒ DeleteCronJob200Response
Delete a cron job Deletes a cron job and its associated AWS resources.
95 96 97 98 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 95 def delete_cron_job(id, opts = {}) data, _status_code, _headers = delete_cron_job_with_http_info(id, opts) data end |
#delete_cron_job_with_http_info(id, opts = {}) ⇒ Array<(DeleteCronJob200Response, Integer, Hash)>
Delete a cron job Deletes a cron job and its associated AWS resources.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 105 def delete_cron_job_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CronApi.delete_cron_job ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CronApi.delete_cron_job" end # resource path local_var_path = '/cron/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteCronJob200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CronApi.delete_cron_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CronApi#delete_cron_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_cron_job(id, opts = {}) ⇒ GetCronJob200Response
Get a cron job by ID Retrieves details of a specific cron job including its schedule and configuration.
158 159 160 161 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 158 def get_cron_job(id, opts = {}) data, _status_code, _headers = get_cron_job_with_http_info(id, opts) data end |
#get_cron_job_with_http_info(id, opts = {}) ⇒ Array<(GetCronJob200Response, Integer, Hash)>
Get a cron job by ID Retrieves details of a specific cron job including its schedule and configuration.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 168 def get_cron_job_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CronApi.get_cron_job ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CronApi.get_cron_job" end # resource path local_var_path = '/cron/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCronJob200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CronApi.get_cron_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CronApi#get_cron_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_cron_invocations(id, opts = {}) ⇒ ListCronInvocations200Response
List cron invocation history Returns a paginated list of delivery attempts and outcomes for a cron job.
224 225 226 227 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 224 def list_cron_invocations(id, opts = {}) data, _status_code, _headers = list_cron_invocations_with_http_info(id, opts) data end |
#list_cron_invocations_with_http_info(id, opts = {}) ⇒ Array<(ListCronInvocations200Response, Integer, Hash)>
List cron invocation history Returns a paginated list of delivery attempts and outcomes for a cron job.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 237 def list_cron_invocations_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CronApi.list_cron_invocations ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CronApi.list_cron_invocations" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CronApi.list_cron_invocations, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CronApi.list_cron_invocations, must be greater than or equal to 1.' end allowable_values = ["delivered", "retrying", "discarded", "abandoned", "enqueued"] if @api_client.config.client_side_validation && opts[:'outcome'] && !allowable_values.include?(opts[:'outcome']) fail ArgumentError, "invalid value for \"outcome\", must be one of #{allowable_values}" end # resource path local_var_path = '/cron/{id}/invocations'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'outcome'] = opts[:'outcome'] if !opts[:'outcome'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCronInvocations200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CronApi.list_cron_invocations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CronApi#list_cron_invocations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_cron_jobs(opts = {}) ⇒ ListCronJobs200Response
List cron jobs Returns a paginated list of cron jobs for the tenant.
306 307 308 309 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 306 def list_cron_jobs(opts = {}) data, _status_code, _headers = list_cron_jobs_with_http_info(opts) data end |
#list_cron_jobs_with_http_info(opts = {}) ⇒ Array<(ListCronJobs200Response, Integer, Hash)>
List cron jobs Returns a paginated list of cron jobs for the tenant.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 317 def list_cron_jobs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CronApi.list_cron_jobs ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CronApi.list_cron_jobs, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CronApi.list_cron_jobs, must be greater than or equal to 1.' end # resource path local_var_path = '/cron' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCronJobs200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CronApi.list_cron_jobs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CronApi#list_cron_jobs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_cron_job(id, opts = {}) ⇒ UpdateCronJob200Response
Update a cron job Updates cron job configuration. Changes require AWS reprovisioning.
377 378 379 380 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 377 def update_cron_job(id, opts = {}) data, _status_code, _headers = update_cron_job_with_http_info(id, opts) data end |
#update_cron_job_with_http_info(id, opts = {}) ⇒ Array<(UpdateCronJob200Response, Integer, Hash)>
Update a cron job Updates cron job configuration. Changes require AWS reprovisioning.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/rocket_stack_sdk/api/cron_api.rb', line 388 def update_cron_job_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CronApi.update_cron_job ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CronApi.update_cron_job" end # resource path local_var_path = '/cron/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'update_cron_job_request']) # return_type return_type = opts[:debug_return_type] || 'UpdateCronJob200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CronApi.update_cron_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CronApi#update_cron_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |