Class: RocketStackSdk::EnqueueMessageRequest

Inherits:
ApiModelBase show all
Defined in:
lib/rocket_stack_sdk/models/enqueue_message_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EnqueueMessageRequest

Initializes the object



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::EnqueueMessageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::EnqueueMessageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'idempotency_key')
    self.idempotency_key = attributes[:'idempotency_key']
  end

  if attributes.key?(:'delay_seconds')
    self.delay_seconds = attributes[:'delay_seconds']
  end
end

Instance Attribute Details

#delay_secondsObject

Returns the value of attribute delay_seconds.



22
23
24
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 22

def delay_seconds
  @delay_seconds
end

#idempotency_keyObject

Returns the value of attribute idempotency_key.



20
21
22
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 20

def idempotency_key
  @idempotency_key
end

#payloadObject

Returns the value of attribute payload.



18
19
20
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 18

def payload
  @payload
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 25

def self.attribute_map
  {
    :'payload' => :'payload',
    :'idempotency_key' => :'idempotencyKey',
    :'delay_seconds' => :'delaySeconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



53
54
55
56
57
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 53

def self.openapi_nullable
  Set.new([
    :'payload',
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 44

def self.openapi_types
  {
    :'payload' => :'Object',
    :'idempotency_key' => :'String',
    :'delay_seconds' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



152
153
154
155
156
157
158
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      payload == o.payload &&
      idempotency_key == o.idempotency_key &&
      delay_seconds == o.delay_seconds
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


162
163
164
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



168
169
170
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 168

def hash
  [payload, idempotency_key, delay_seconds].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 90

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@idempotency_key.nil? && @idempotency_key.to_s.length > 128
    invalid_properties.push('invalid value for "idempotency_key", the character length must be smaller than or equal to 128.')
  end

  if !@delay_seconds.nil? && @delay_seconds > 900
    invalid_properties.push('invalid value for "delay_seconds", must be smaller than or equal to 900.')
  end

  if !@delay_seconds.nil? && @delay_seconds < 0
    invalid_properties.push('invalid value for "delay_seconds", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



110
111
112
113
114
115
116
# File 'lib/rocket_stack_sdk/models/enqueue_message_request.rb', line 110

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@idempotency_key.nil? && @idempotency_key.to_s.length > 128
  return false if !@delay_seconds.nil? && @delay_seconds > 900
  return false if !@delay_seconds.nil? && @delay_seconds < 0
  true
end