Class: RocketStackSdk::InvokeFunctionRequest

Inherits:
ApiModelBase show all
Defined in:
lib/rocket_stack_sdk/models/invoke_function_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvokeFunctionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::InvokeFunctionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::InvokeFunctionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'invocation_type')
    self.invocation_type = attributes[:'invocation_type']
  else
    self.invocation_type = 'RequestResponse'
  end

  if attributes.key?(:'include_logs')
    self.include_logs = attributes[:'include_logs']
  else
    self.include_logs = false
  end
end

Instance Attribute Details

#include_logsObject

Returns the value of attribute include_logs.



22
23
24
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 22

def include_logs
  @include_logs
end

#invocation_typeObject

Returns the value of attribute invocation_type.



20
21
22
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 20

def invocation_type
  @invocation_type
end

#payloadObject

Returns the value of attribute payload.



18
19
20
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 18

def payload
  @payload
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 47

def self.attribute_map
  {
    :'payload' => :'payload',
    :'invocation_type' => :'invocationType',
    :'include_logs' => :'includeLogs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 166

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
79
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 75

def self.openapi_nullable
  Set.new([
    :'payload',
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 66

def self.openapi_types
  {
    :'payload' => :'Object',
    :'invocation_type' => :'String',
    :'include_logs' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
149
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      payload == o.payload &&
      invocation_type == o.invocation_type &&
      include_logs == o.include_logs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


153
154
155
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 153

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



159
160
161
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 159

def hash
  [payload, invocation_type, include_logs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
128
129
# File 'lib/rocket_stack_sdk/models/invoke_function_request.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  invocation_type_validator = EnumAttributeValidator.new('String', ["RequestResponse", "Event"])
  return false unless invocation_type_validator.valid?(@invocation_type)
  true
end