Class: RocketStackSdk::ListCronInvocations200ResponseDataItemsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListCronInvocations200ResponseDataItemsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListCronInvocations200ResponseDataItemsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListCronInvocations200ResponseDataItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'invocation_id')
    self.invocation_id = attributes[:'invocation_id']
  else
    self.invocation_id = nil
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'outcome')
    self.outcome = attributes[:'outcome']
  else
    self.outcome = nil
  end

  if attributes.key?(:'occurred_at')
    self.occurred_at = attributes[:'occurred_at']
  else
    self.occurred_at = nil
  end

  if attributes.key?(:'attempt')
    self.attempt = attributes[:'attempt']
  end

  if attributes.key?(:'duration_ms')
    self.duration_ms = attributes[:'duration_ms']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'trigger_id')
    self.trigger_id = attributes[:'trigger_id']
  end

  if attributes.key?(:'target_type')
    self.target_type = attributes[:'target_type']
  end

  if attributes.key?(:'trigger_source')
    self.trigger_source = attributes[:'trigger_source']
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'backoff_seconds')
    self.backoff_seconds = attributes[:'backoff_seconds']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



20
21
22
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 20

def action
  @action
end

#attemptObject

Returns the value of attribute attempt.



26
27
28
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 26

def attempt
  @attempt
end

#backoff_secondsObject

Returns the value of attribute backoff_seconds.



42
43
44
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 42

def backoff_seconds
  @backoff_seconds
end

#duration_msObject

Returns the value of attribute duration_ms.



28
29
30
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 28

def duration_ms
  @duration_ms
end

#errorObject

Returns the value of attribute error.



30
31
32
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 30

def error
  @error
end

#invocation_idObject

Returns the value of attribute invocation_id.



18
19
20
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 18

def invocation_id
  @invocation_id
end

#occurred_atObject

Returns the value of attribute occurred_at.



24
25
26
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 24

def occurred_at
  @occurred_at
end

#outcomeObject

Returns the value of attribute outcome.



22
23
24
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 22

def outcome
  @outcome
end

#reasonObject

Returns the value of attribute reason.



32
33
34
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 32

def reason
  @reason
end

#status_codeObject

Returns the value of attribute status_code.



40
41
42
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 40

def status_code
  @status_code
end

#target_typeObject

Returns the value of attribute target_type.



36
37
38
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 36

def target_type
  @target_type
end

#trigger_idObject

Returns the value of attribute trigger_id.



34
35
36
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 34

def trigger_id
  @trigger_id
end

#trigger_sourceObject

Returns the value of attribute trigger_source.



38
39
40
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 38

def trigger_source
  @trigger_source
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 67

def self.attribute_map
  {
    :'invocation_id' => :'invocationId',
    :'action' => :'action',
    :'outcome' => :'outcome',
    :'occurred_at' => :'occurredAt',
    :'attempt' => :'attempt',
    :'duration_ms' => :'durationMs',
    :'error' => :'error',
    :'reason' => :'reason',
    :'trigger_id' => :'triggerId',
    :'target_type' => :'targetType',
    :'trigger_source' => :'triggerSource',
    :'status_code' => :'statusCode',
    :'backoff_seconds' => :'backoffSeconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 309

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 96

def self.openapi_types
  {
    :'invocation_id' => :'String',
    :'action' => :'String',
    :'outcome' => :'String',
    :'occurred_at' => :'String',
    :'attempt' => :'Float',
    :'duration_ms' => :'Float',
    :'error' => :'String',
    :'reason' => :'String',
    :'trigger_id' => :'String',
    :'target_type' => :'String',
    :'trigger_source' => :'String',
    :'status_code' => :'Float',
    :'backoff_seconds' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 276

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      invocation_id == o.invocation_id &&
      action == o.action &&
      outcome == o.outcome &&
      occurred_at == o.occurred_at &&
      attempt == o.attempt &&
      duration_ms == o.duration_ms &&
      error == o.error &&
      reason == o.reason &&
      trigger_id == o.trigger_id &&
      target_type == o.target_type &&
      trigger_source == o.trigger_source &&
      status_code == o.status_code &&
      backoff_seconds == o.backoff_seconds
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


296
297
298
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 296

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



302
303
304
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 302

def hash
  [invocation_id, action, outcome, occurred_at, attempt, duration_ms, error, reason, trigger_id, target_type, trigger_source, status_code, backoff_seconds].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 199

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @invocation_id.nil?
    invalid_properties.push('invalid value for "invocation_id", invocation_id cannot be nil.')
  end

  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @outcome.nil?
    invalid_properties.push('invalid value for "outcome", outcome cannot be nil.')
  end

  if @occurred_at.nil?
    invalid_properties.push('invalid value for "occurred_at", occurred_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 331

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
228
229
230
231
232
# File 'lib/rocket_stack_sdk/models/list_cron_invocations200_response_data_items_inner.rb', line 223

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @invocation_id.nil?
  return false if @action.nil?
  return false if @outcome.nil?
  outcome_validator = EnumAttributeValidator.new('String', ["delivered", "retrying", "discarded", "abandoned", "enqueued"])
  return false unless outcome_validator.valid?(@outcome)
  return false if @occurred_at.nil?
  true
end