Class: RocketStackSdk::ListCronJobs200ResponseDataItemsInnerSchedule

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListCronJobs200ResponseDataItemsInnerSchedule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListCronJobs200ResponseDataItemsInnerSchedule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListCronJobs200ResponseDataItemsInnerSchedule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'expression')
    self.expression = attributes[:'expression']
  else
    self.expression = nil
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = nil
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  else
    self.timezone = nil
  end

  if attributes.key?(:'expression_normalized')
    self.expression_normalized = attributes[:'expression_normalized']
  end
end

Instance Attribute Details

#expressionObject

Returns the value of attribute expression.



18
19
20
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 18

def expression
  @expression
end

#expression_normalizedObject

Returns the value of attribute expression_normalized.



24
25
26
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 24

def expression_normalized
  @expression_normalized
end

#formatObject

Returns the value of attribute format.



20
21
22
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 20

def format
  @format
end

#timezoneObject

Returns the value of attribute timezone.



22
23
24
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 22

def timezone
  @timezone
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 49

def self.attribute_map
  {
    :'expression' => :'expression',
    :'format' => :'format',
    :'timezone' => :'timezone',
    :'expression_normalized' => :'expressionNormalized'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 69

def self.openapi_types
  {
    :'expression' => :'String',
    :'format' => :'String',
    :'timezone' => :'String',
    :'expression_normalized' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      expression == o.expression &&
      format == o.format &&
      timezone == o.timezone &&
      expression_normalized == o.expression_normalized
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 204

def hash
  [expression, format, timezone, expression_normalized].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expression.nil?
    invalid_properties.push('invalid value for "expression", expression cannot be nil.')
  end

  if @format.nil?
    invalid_properties.push('invalid value for "format", format cannot be nil.')
  end

  if @timezone.nil?
    invalid_properties.push('invalid value for "timezone", timezone cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
152
153
# File 'lib/rocket_stack_sdk/models/list_cron_jobs200_response_data_items_inner_schedule.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expression.nil?
  return false if @format.nil?
  format_validator = EnumAttributeValidator.new('String', ["aws", "unix5"])
  return false unless format_validator.valid?(@format)
  return false if @timezone.nil?
  true
end