Class: RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpecCode
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpecCode
- Defined in:
- lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb
Instance Attribute Summary collapse
-
#has_code ⇒ Object
Returns the value of attribute has_code.
-
#revision_id ⇒ Object
Returns the value of attribute revision_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListFunctions200ResponseDataItemsInnerDesiredSpecCode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListFunctions200ResponseDataItemsInnerDesiredSpecCode
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpecCode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpecCode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'has_code') self.has_code = attributes[:'has_code'] else self.has_code = nil end if attributes.key?(:'revision_id') self.revision_id = attributes[:'revision_id'] end end |
Instance Attribute Details
#has_code ⇒ Object
Returns the value of attribute has_code.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 18 def has_code @has_code end |
#revision_id ⇒ Object
Returns the value of attribute revision_id.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 20 def revision_id @revision_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
31 32 33 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 31 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
36 37 38 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 36 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 23 def self.attribute_map { :'has_code' => :'hasCode', :'revision_id' => :'revisionId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 136 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
49 50 51 52 53 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 49 def self.openapi_nullable Set.new([ :'revision_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 41 def self.openapi_types { :'has_code' => :'Boolean', :'revision_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
114 115 116 117 118 119 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 114 def ==(o) return true if self.equal?(o) self.class == o.class && has_code == o.has_code && revision_id == o.revision_id end |
#eql?(o) ⇒ Boolean
123 124 125 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 123 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
129 130 131 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 129 def hash [has_code, revision_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
84 85 86 87 88 89 90 91 92 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 84 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @has_code.nil? invalid_properties.push('invalid value for "has_code", has_code cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
96 97 98 99 100 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec_code.rb', line 96 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @has_code.nil? true end |