Class: RocketStackSdk::ListQueueMessages200ResponseDataItemsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListQueueMessages200ResponseDataItemsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListQueueMessages200ResponseDataItemsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListQueueMessages200ResponseDataItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'message_id')
    self.message_id = attributes[:'message_id']
  else
    self.message_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'attempts')
    self.attempts = attributes[:'attempts']
  else
    self.attempts = nil
  end

  if attributes.key?(:'last_error')
    self.last_error = attributes[:'last_error']
  end

  if attributes.key?(:'payload_size_bytes')
    self.payload_size_bytes = attributes[:'payload_size_bytes']
  else
    self.payload_size_bytes = nil
  end

  if attributes.key?(:'idempotency_key')
    self.idempotency_key = attributes[:'idempotency_key']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#attemptsObject

Returns the value of attribute attempts.



22
23
24
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 22

def attempts
  @attempts
end

#created_atObject

Returns the value of attribute created_at.



30
31
32
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 30

def created_at
  @created_at
end

#idempotency_keyObject

Returns the value of attribute idempotency_key.



28
29
30
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 28

def idempotency_key
  @idempotency_key
end

#last_errorObject

Returns the value of attribute last_error.



24
25
26
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 24

def last_error
  @last_error
end

#message_idObject

Returns the value of attribute message_id.



18
19
20
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 18

def message_id
  @message_id
end

#payload_size_bytesObject

Returns the value of attribute payload_size_bytes.



26
27
28
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 26

def payload_size_bytes
  @payload_size_bytes
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 20

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



32
33
34
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 32

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 35

def self.attribute_map
  {
    :'message_id' => :'messageId',
    :'status' => :'status',
    :'attempts' => :'attempts',
    :'last_error' => :'lastError',
    :'payload_size_bytes' => :'payloadSizeBytes',
    :'idempotency_key' => :'idempotencyKey',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 59

def self.openapi_types
  {
    :'message_id' => :'String',
    :'status' => :'String',
    :'attempts' => :'Float',
    :'last_error' => :'String',
    :'payload_size_bytes' => :'Float',
    :'idempotency_key' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      message_id == o.message_id &&
      status == o.status &&
      attempts == o.attempts &&
      last_error == o.last_error &&
      payload_size_bytes == o.payload_size_bytes &&
      idempotency_key == o.idempotency_key &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 267

def hash
  [message_id, status, attempts, last_error, payload_size_bytes, idempotency_key, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @message_id.nil?
    invalid_properties.push('invalid value for "message_id", message_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @attempts.nil?
    invalid_properties.push('invalid value for "attempts", attempts cannot be nil.')
  end

  if @payload_size_bytes.nil?
    invalid_properties.push('invalid value for "payload_size_bytes", payload_size_bytes cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
180
181
182
# File 'lib/rocket_stack_sdk/models/list_queue_messages200_response_data_items_inner.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @message_id.nil?
  return false if @status.nil?
  return false if @attempts.nil?
  return false if @payload_size_bytes.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end