Class: RocketStackSdk::ListQueues200ResponseDataItemsInnerDeliveryTarget

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListQueues200ResponseDataItemsInnerDeliveryTarget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListQueues200ResponseDataItemsInnerDeliveryTarget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListQueues200ResponseDataItemsInnerDeliveryTarget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'function_id')
    self.function_id = attributes[:'function_id']
  end

  if attributes.key?(:'webhook_url')
    self.webhook_url = attributes[:'webhook_url']
  end

  if attributes.key?(:'timeout_seconds')
    self.timeout_seconds = attributes[:'timeout_seconds']
  else
    self.timeout_seconds = nil
  end

  if attributes.key?(:'max_in_flight')
    self.max_in_flight = attributes[:'max_in_flight']
  else
    self.max_in_flight = nil
  end

  if attributes.key?(:'max_per_second')
    self.max_per_second = attributes[:'max_per_second']
  end
end

Instance Attribute Details

#function_idObject

Returns the value of attribute function_id.



20
21
22
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 20

def function_id
  @function_id
end

#max_in_flightObject

Returns the value of attribute max_in_flight.



26
27
28
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 26

def max_in_flight
  @max_in_flight
end

#max_per_secondObject

Returns the value of attribute max_per_second.



28
29
30
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 28

def max_per_second
  @max_per_second
end

#timeout_secondsObject

Returns the value of attribute timeout_seconds.



24
25
26
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 24

def timeout_seconds
  @timeout_seconds
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 18

def type
  @type
end

#webhook_urlObject

Returns the value of attribute webhook_url.



22
23
24
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 22

def webhook_url
  @webhook_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 53

def self.attribute_map
  {
    :'type' => :'type',
    :'function_id' => :'functionId',
    :'webhook_url' => :'webhookUrl',
    :'timeout_seconds' => :'timeoutSeconds',
    :'max_in_flight' => :'maxInFlight',
    :'max_per_second' => :'maxPerSecond'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 229

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 75

def self.openapi_types
  {
    :'type' => :'String',
    :'function_id' => :'String',
    :'webhook_url' => :'String',
    :'timeout_seconds' => :'Float',
    :'max_in_flight' => :'Float',
    :'max_per_second' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
211
212
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      function_id == o.function_id &&
      webhook_url == o.webhook_url &&
      timeout_seconds == o.timeout_seconds &&
      max_in_flight == o.max_in_flight &&
      max_per_second == o.max_per_second
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


216
217
218
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 216

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



222
223
224
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 222

def hash
  [type, function_id, webhook_url, timeout_seconds, max_in_flight, max_per_second].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @timeout_seconds.nil?
    invalid_properties.push('invalid value for "timeout_seconds", timeout_seconds cannot be nil.')
  end

  if @max_in_flight.nil?
    invalid_properties.push('invalid value for "max_in_flight", max_in_flight cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
167
168
169
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner_delivery_target.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["function", "webhook"])
  return false unless type_validator.valid?(@type)
  return false if @timeout_seconds.nil?
  return false if @max_in_flight.nil?
  true
end