Class: RocketStackSdk::ListSchedules200ResponseDataItemsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListSchedules200ResponseDataItemsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListSchedules200ResponseDataItemsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListSchedules200ResponseDataItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'resource_key')
    self.resource_key = attributes[:'resource_key']
  else
    self.resource_key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'run_at')
    self.run_at = attributes[:'run_at']
  else
    self.run_at = nil
  end

  if attributes.key?(:'delivery_target')
    self.delivery_target = attributes[:'delivery_target']
  else
    self.delivery_target = nil
  end

  if attributes.key?(:'paused')
    self.paused = attributes[:'paused']
  else
    self.paused = nil
  end

  if attributes.key?(:'payload_template')
    if (value = attributes[:'payload_template']).is_a?(Hash)
      self.payload_template = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 34

def created_at
  @created_at
end

#delivery_targetObject

Returns the value of attribute delivery_target.



28
29
30
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 28

def delivery_target
  @delivery_target
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



22
23
24
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 22

def name
  @name
end

#pausedObject

Returns the value of attribute paused.



30
31
32
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 30

def paused
  @paused
end

#payload_templateObject

Returns the value of attribute payload_template.



32
33
34
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 32

def payload_template
  @payload_template
end

#resource_keyObject

Returns the value of attribute resource_key.



20
21
22
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 20

def resource_key
  @resource_key
end

#run_atObject

Returns the value of attribute run_at.



26
27
28
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 26

def run_at
  @run_at
end

#statusObject

Returns the value of attribute status.



24
25
26
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 24

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



36
37
38
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 36

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 39

def self.attribute_map
  {
    :'id' => :'id',
    :'resource_key' => :'resourceKey',
    :'name' => :'name',
    :'status' => :'status',
    :'run_at' => :'runAt',
    :'delivery_target' => :'deliveryTarget',
    :'paused' => :'paused',
    :'payload_template' => :'payloadTemplate',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 346

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 81

def self.openapi_nullable
  Set.new([
    :'payload_template',
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 65

def self.openapi_types
  {
    :'id' => :'String',
    :'resource_key' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'run_at' => :'String',
    :'delivery_target' => :'ListQueues200ResponseDataItemsInnerDeliveryTarget',
    :'paused' => :'Boolean',
    :'payload_template' => :'Hash<String, Object>',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 316

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      resource_key == o.resource_key &&
      name == o.name &&
      status == o.status &&
      run_at == o.run_at &&
      delivery_target == o.delivery_target &&
      paused == o.paused &&
      payload_template == o.payload_template &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


333
334
335
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 333

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



339
340
341
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 339

def hash
  [id, resource_key, name, status, run_at, delivery_target, paused, payload_template, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @resource_key.nil?
    invalid_properties.push('invalid value for "resource_key", resource_key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @run_at.nil?
    invalid_properties.push('invalid value for "run_at", run_at cannot be nil.')
  end

  if @delivery_target.nil?
    invalid_properties.push('invalid value for "delivery_target", delivery_target cannot be nil.')
  end

  if @paused.nil?
    invalid_properties.push('invalid value for "paused", paused cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/rocket_stack_sdk/models/list_schedules200_response_data_items_inner.rb', line 210

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @resource_key.nil?
  return false if @name.nil?
  return false if @status.nil?
  return false if @run_at.nil?
  return false if @delivery_target.nil?
  return false if @paused.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end