Class: RocketStackSdk::ListSnippets200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListSnippets200ResponseDataInner

Initializes the object



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListSnippets200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListSnippets200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'capability')
    self.capability = attributes[:'capability']
  else
    self.capability = nil
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  else
    self.language = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end
end

Instance Attribute Details

#capabilityObject

Returns the value of attribute capability.



20
21
22
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 20

def capability
  @capability
end

#codeObject

Returns the value of attribute code.



28
29
30
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 28

def code
  @code
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 26

def description
  @description
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 18

def id
  @id
end

#languageObject

Returns the value of attribute language.



22
23
24
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 22

def language
  @language
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 24

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 31

def self.attribute_map
  {
    :'id' => :'id',
    :'capability' => :'capability',
    :'language' => :'language',
    :'name' => :'name',
    :'description' => :'description',
    :'code' => :'code'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 53

def self.openapi_types
  {
    :'id' => :'String',
    :'capability' => :'String',
    :'language' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



230
231
232
233
234
235
236
237
238
239
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      capability == o.capability &&
      language == o.language &&
      name == o.name &&
      description == o.description &&
      code == o.code
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


243
244
245
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



249
250
251
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 249

def hash
  [id, capability, language, name, description, code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @capability.nil?
    invalid_properties.push('invalid value for "capability", capability cannot be nil.')
  end

  if @language.nil?
    invalid_properties.push('invalid value for "language", language cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



157
158
159
160
161
162
163
164
165
166
# File 'lib/rocket_stack_sdk/models/list_snippets200_response_data_inner.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @capability.nil?
  return false if @language.nil?
  return false if @name.nil?
  return false if @description.nil?
  return false if @code.nil?
  true
end