Class: RocketStackSdk::ListStorageObjects200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::ListStorageObjects200ResponseData
- Defined in:
- lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb
Instance Attribute Summary collapse
-
#items ⇒ Object
Returns the value of attribute items.
-
#next_cursor ⇒ Object
Returns the value of attribute next_cursor.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListStorageObjects200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListStorageObjects200ResponseData
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListStorageObjects200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListStorageObjects200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'items') if (value = attributes[:'items']).is_a?(Array) self.items = value end else self.items = nil end if attributes.key?(:'next_cursor') self.next_cursor = attributes[:'next_cursor'] else self.next_cursor = nil end end |
Instance Attribute Details
#items ⇒ Object
Returns the value of attribute items.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 18 def items @items end |
#next_cursor ⇒ Object
Returns the value of attribute next_cursor.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 20 def next_cursor @next_cursor end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
31 32 33 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 31 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
36 37 38 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 36 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 23 def self.attribute_map { :'items' => :'items', :'next_cursor' => :'nextCursor' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 140 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
49 50 51 52 53 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 49 def self.openapi_nullable Set.new([ :'next_cursor' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 41 def self.openapi_types { :'items' => :'Array<ListStorageObjects200ResponseDataItemsInner>', :'next_cursor' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 118 def ==(o) return true if self.equal?(o) self.class == o.class && items == o.items && next_cursor == o.next_cursor end |
#eql?(o) ⇒ Boolean
127 128 129 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 127 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 133 def hash [items, next_cursor].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
88 89 90 91 92 93 94 95 96 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 88 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @items.nil? invalid_properties.push('invalid value for "items", items cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
100 101 102 103 104 |
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data.rb', line 100 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @items.nil? true end |