Class: RocketStackSdk::ListStorageObjects200ResponseDataItemsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListStorageObjects200ResponseDataItemsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListStorageObjects200ResponseDataItemsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListStorageObjects200ResponseDataItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = nil
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  else
    self.size_bytes = nil
  end

  if attributes.key?(:'last_modified')
    self.last_modified = attributes[:'last_modified']
  else
    self.last_modified = nil
  end

  if attributes.key?(:'etag')
    self.etag = attributes[:'etag']
  else
    self.etag = nil
  end

  if attributes.key?(:'is_public')
    self.is_public = attributes[:'is_public']
  end

  if attributes.key?(:'public_url')
    self.public_url = attributes[:'public_url']
  end
end

Instance Attribute Details

#etagObject

Returns the value of attribute etag.



24
25
26
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 24

def etag
  @etag
end

#is_publicObject

Returns the value of attribute is_public.



26
27
28
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 26

def is_public
  @is_public
end

#last_modifiedObject

Returns the value of attribute last_modified.



22
23
24
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 22

def last_modified
  @last_modified
end

#pathObject

Returns the value of attribute path.



18
19
20
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 18

def path
  @path
end

#public_urlObject

Returns the value of attribute public_url.



28
29
30
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 28

def public_url
  @public_url
end

#size_bytesObject

Returns the value of attribute size_bytes.



20
21
22
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 20

def size_bytes
  @size_bytes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 31

def self.attribute_map
  {
    :'path' => :'path',
    :'size_bytes' => :'sizeBytes',
    :'last_modified' => :'lastModified',
    :'etag' => :'etag',
    :'is_public' => :'isPublic',
    :'public_url' => :'publicUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 53

def self.openapi_types
  {
    :'path' => :'String',
    :'size_bytes' => :'Float',
    :'last_modified' => :'String',
    :'etag' => :'String',
    :'is_public' => :'Boolean',
    :'public_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
204
205
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      path == o.path &&
      size_bytes == o.size_bytes &&
      last_modified == o.last_modified &&
      etag == o.etag &&
      is_public == o.is_public &&
      public_url == o.public_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 215

def hash
  [path, size_bytes, last_modified, etag, is_public, public_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @path.nil?
    invalid_properties.push('invalid value for "path", path cannot be nil.')
  end

  if @size_bytes.nil?
    invalid_properties.push('invalid value for "size_bytes", size_bytes cannot be nil.')
  end

  if @last_modified.nil?
    invalid_properties.push('invalid value for "last_modified", last_modified cannot be nil.')
  end

  if @etag.nil?
    invalid_properties.push('invalid value for "etag", etag cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
152
# File 'lib/rocket_stack_sdk/models/list_storage_objects200_response_data_items_inner.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @path.nil?
  return false if @size_bytes.nil?
  return false if @last_modified.nil?
  return false if @etag.nil?
  true
end