Class: RocketStackSdk::PutKvItemRequest

Inherits:
ApiModelBase show all
Defined in:
lib/rocket_stack_sdk/models/put_kv_item_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PutKvItemRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::PutKvItemRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::PutKvItemRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'ttl_seconds')
    self.ttl_seconds = attributes[:'ttl_seconds']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'if_version')
    self.if_version = attributes[:'if_version']
  end
end

Instance Attribute Details

#expires_atObject

Returns the value of attribute expires_at.



22
23
24
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 22

def expires_at
  @expires_at
end

#if_versionObject

Returns the value of attribute if_version.



24
25
26
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 24

def if_version
  @if_version
end

#ttl_secondsObject

Returns the value of attribute ttl_seconds.



20
21
22
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 20

def ttl_seconds
  @ttl_seconds
end

#valueObject

Returns the value of attribute value.



18
19
20
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 18

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 27

def self.attribute_map
  {
    :'value' => :'value',
    :'ttl_seconds' => :'ttlSeconds',
    :'expires_at' => :'expiresAt',
    :'if_version' => :'ifVersion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 165

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 57

def self.openapi_nullable
  Set.new([
    :'value',
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 47

def self.openapi_types
  {
    :'value' => :'Object',
    :'ttl_seconds' => :'Integer',
    :'expires_at' => :'String',
    :'if_version' => :'PutKvItemRequestIfVersion'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      value == o.value &&
      ttl_seconds == o.ttl_seconds &&
      expires_at == o.expires_at &&
      if_version == o.if_version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 158

def hash
  [value, ttl_seconds, expires_at, if_version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 98

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@ttl_seconds.nil? && @ttl_seconds > 2592000
    invalid_properties.push('invalid value for "ttl_seconds", must be smaller than or equal to 2592000.')
  end

  if !@ttl_seconds.nil? && @ttl_seconds < 1
    invalid_properties.push('invalid value for "ttl_seconds", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



114
115
116
117
118
119
# File 'lib/rocket_stack_sdk/models/put_kv_item_request.rb', line 114

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@ttl_seconds.nil? && @ttl_seconds > 2592000
  return false if !@ttl_seconds.nil? && @ttl_seconds < 1
  true
end