Class: RocketStackSdk::QueuesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/rocket_stack_sdk/api/queues_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ QueuesApi

Returns a new instance of QueuesApi.



19
20
21
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_queue(create_queue_request, opts = {}) ⇒ CreateQueue201Response

Create a new queue Creates a new message queue with optional delivery target configuration.

Parameters:

  • create_queue_request (CreateQueueRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 27

def create_queue(create_queue_request, opts = {})
  data, _status_code, _headers = create_queue_with_http_info(create_queue_request, opts)
  data
end

#create_queue_with_http_info(create_queue_request, opts = {}) ⇒ Array<(CreateQueue201Response, Integer, Hash)>

Create a new queue Creates a new message queue with optional delivery target configuration.

Parameters:

  • create_queue_request (CreateQueueRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreateQueue201Response, Integer, Hash)>)

    CreateQueue201Response data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 37

def create_queue_with_http_info(create_queue_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: QueuesApi.create_queue ...'
  end
  # verify the required parameter 'create_queue_request' is set
  if @api_client.config.client_side_validation && create_queue_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_queue_request' when calling QueuesApi.create_queue"
  end
  # resource path
  local_var_path = '/queues'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_queue_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateQueue201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"QueuesApi.create_queue",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: QueuesApi#create_queue\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_queue(id, opts = {}) ⇒ CreateQueue201Response

Delete a queue Deletes a queue and its associated resources.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



95
96
97
98
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 95

def delete_queue(id, opts = {})
  data, _status_code, _headers = delete_queue_with_http_info(id, opts)
  data
end

#delete_queue_with_http_info(id, opts = {}) ⇒ Array<(CreateQueue201Response, Integer, Hash)>

Delete a queue Deletes a queue and its associated resources.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreateQueue201Response, Integer, Hash)>)

    CreateQueue201Response data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 105

def delete_queue_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: QueuesApi.delete_queue ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling QueuesApi.delete_queue"
  end
  # resource path
  local_var_path = '/queues/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CreateQueue201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"QueuesApi.delete_queue",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: QueuesApi#delete_queue\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enqueue_message(id, opts = {}) ⇒ EnqueueMessage201Response

Enqueue a message Adds a message to the queue for processing.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



159
160
161
162
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 159

def enqueue_message(id, opts = {})
  data, _status_code, _headers = enqueue_message_with_http_info(id, opts)
  data
end

#enqueue_message_with_http_info(id, opts = {}) ⇒ Array<(EnqueueMessage201Response, Integer, Hash)>

Enqueue a message Adds a message to the queue for processing.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(EnqueueMessage201Response, Integer, Hash)>)

    EnqueueMessage201Response data, response status code and response headers



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 170

def enqueue_message_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: QueuesApi.enqueue_message ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling QueuesApi.enqueue_message"
  end
  # resource path
  local_var_path = '/queues/{id}/messages'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'enqueue_message_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'EnqueueMessage201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"QueuesApi.enqueue_message",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: QueuesApi#enqueue_message\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_message_status(id, message_id, opts = {}) ⇒ GetMessageStatus200Response

Get message status Retrieves the current status of a message in the queue.

Parameters:

  • id (String)
  • message_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



229
230
231
232
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 229

def get_message_status(id, message_id, opts = {})
  data, _status_code, _headers = get_message_status_with_http_info(id, message_id, opts)
  data
end

#get_message_status_with_http_info(id, message_id, opts = {}) ⇒ Array<(GetMessageStatus200Response, Integer, Hash)>

Get message status Retrieves the current status of a message in the queue.

Parameters:

  • id (String)
  • message_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetMessageStatus200Response, Integer, Hash)>)

    GetMessageStatus200Response data, response status code and response headers



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 240

def get_message_status_with_http_info(id, message_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: QueuesApi.get_message_status ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling QueuesApi.get_message_status"
  end
  # verify the required parameter 'message_id' is set
  if @api_client.config.client_side_validation && message_id.nil?
    fail ArgumentError, "Missing the required parameter 'message_id' when calling QueuesApi.get_message_status"
  end
  # resource path
  local_var_path = '/queues/{id}/messages/{messageId}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'messageId' + '}', CGI.escape(message_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetMessageStatus200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"QueuesApi.get_message_status",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: QueuesApi#get_message_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_queue(id, opts = {}) ⇒ GetQueue200Response

Get a queue by ID Retrieves details of a specific queue including its configuration.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



297
298
299
300
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 297

def get_queue(id, opts = {})
  data, _status_code, _headers = get_queue_with_http_info(id, opts)
  data
end

#get_queue_with_http_info(id, opts = {}) ⇒ Array<(GetQueue200Response, Integer, Hash)>

Get a queue by ID Retrieves details of a specific queue including its configuration.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetQueue200Response, Integer, Hash)>)

    GetQueue200Response data, response status code and response headers



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 307

def get_queue_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: QueuesApi.get_queue ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling QueuesApi.get_queue"
  end
  # resource path
  local_var_path = '/queues/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetQueue200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"QueuesApi.get_queue",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: QueuesApi#get_queue\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_queues(opts = {}) ⇒ ListQueues200Response

List queues Returns a paginated list of queues for the tenant.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Float) — default: default to 50
  • :cursor (String)

Returns:



361
362
363
364
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 361

def list_queues(opts = {})
  data, _status_code, _headers = list_queues_with_http_info(opts)
  data
end

#list_queues_with_http_info(opts = {}) ⇒ Array<(ListQueues200Response, Integer, Hash)>

List queues Returns a paginated list of queues for the tenant.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Float) — default: default to 50
  • :cursor (String)

Returns:

  • (Array<(ListQueues200Response, Integer, Hash)>)

    ListQueues200Response data, response status code and response headers



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 372

def list_queues_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: QueuesApi.list_queues ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling QueuesApi.list_queues, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling QueuesApi.list_queues, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/queues'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListQueues200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"QueuesApi.list_queues",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: QueuesApi#list_queues\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_queue(id, opts = {}) ⇒ UpdateQueue200Response

Update a queue Updates queue configuration. Some changes may require reprovisioning.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



432
433
434
435
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 432

def update_queue(id, opts = {})
  data, _status_code, _headers = update_queue_with_http_info(id, opts)
  data
end

#update_queue_with_http_info(id, opts = {}) ⇒ Array<(UpdateQueue200Response, Integer, Hash)>

Update a queue Updates queue configuration. Some changes may require reprovisioning.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(UpdateQueue200Response, Integer, Hash)>)

    UpdateQueue200Response data, response status code and response headers



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/rocket_stack_sdk/api/queues_api.rb', line 443

def update_queue_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: QueuesApi.update_queue ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling QueuesApi.update_queue"
  end
  # resource path
  local_var_path = '/queues/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'update_queue_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateQueue200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"QueuesApi.update_queue",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: QueuesApi#update_queue\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end