Class: RocketStackSdk::ResourcesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/rocket_stack_sdk/api/resources_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ResourcesApi

Returns a new instance of ResourcesApi.



19
20
21
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_template(id, opts = {}) ⇒ GetTemplate200Response

Get a template by id Returns a single app template with optional code.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 27

def get_template(id, opts = {})
  data, _status_code, _headers = get_template_with_http_info(id, opts)
  data
end

#get_template_with_http_info(id, opts = {}) ⇒ Array<(GetTemplate200Response, Integer, Hash)>

Get a template by id Returns a single app template with optional code.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetTemplate200Response, Integer, Hash)>)

    GetTemplate200Response data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 37

def get_template_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ResourcesApi.get_template ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling ResourcesApi.get_template"
  end
  if @api_client.config.client_side_validation && id.to_s.length < 1
    fail ArgumentError, 'invalid value for "id" when calling ResourcesApi.get_template, the character length must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/resources/templates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetTemplate200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ResourcesApi.get_template",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ResourcesApi#get_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_capabilities(opts = {}) ⇒ ListCapabilities200Response

List app-generation capabilities Returns capabilities (e.g. functions, queues, kv) with id, name, description. Used by MCP/Cursor to map user intent to capability IDs.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



93
94
95
96
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 93

def list_capabilities(opts = {})
  data, _status_code, _headers = list_capabilities_with_http_info(opts)
  data
end

#list_capabilities_with_http_info(opts = {}) ⇒ Array<(ListCapabilities200Response, Integer, Hash)>

List app-generation capabilities Returns capabilities (e.g. functions, queues, kv) with id, name, description. Used by MCP/Cursor to map user intent to capability IDs.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ListCapabilities200Response, Integer, Hash)>)

    ListCapabilities200Response data, response status code and response headers



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 102

def list_capabilities_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ResourcesApi.list_capabilities ...'
  end
  # resource path
  local_var_path = '/resources/capabilities'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListCapabilities200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ResourcesApi.list_capabilities",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ResourcesApi#list_capabilities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_snippets(opts = {}) ⇒ ListSnippets200Response

List code snippets Returns snippets. Query params: capability (e.g. queue, kv), language (e.g. node, python).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :capability (String)
  • :language (String)

Returns:



152
153
154
155
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 152

def list_snippets(opts = {})
  data, _status_code, _headers = list_snippets_with_http_info(opts)
  data
end

#list_snippets_with_http_info(opts = {}) ⇒ Array<(ListSnippets200Response, Integer, Hash)>

List code snippets Returns snippets. Query params: capability (e.g. queue, kv), language (e.g. node, python).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :capability (String)
  • :language (String)

Returns:

  • (Array<(ListSnippets200Response, Integer, Hash)>)

    ListSnippets200Response data, response status code and response headers



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 163

def list_snippets_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ResourcesApi.list_snippets ...'
  end
  if @api_client.config.client_side_validation && !opts[:'capability'].nil? && opts[:'capability'].to_s.length < 1
    fail ArgumentError, 'invalid value for "opts[:"capability"]" when calling ResourcesApi.list_snippets, the character length must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'language'].nil? && opts[:'language'].to_s.length < 1
    fail ArgumentError, 'invalid value for "opts[:"language"]" when calling ResourcesApi.list_snippets, the character length must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/resources/snippets'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'capability'] = opts[:'capability'] if !opts[:'capability'].nil?
  query_params[:'language'] = opts[:'language'] if !opts[:'language'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListSnippets200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ResourcesApi.list_snippets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ResourcesApi#list_snippets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_templates(opts = {}) ⇒ ListTemplates200Response

List app templates Returns app templates. Optional query: capabilities=queue,kv to filter by capability.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :capabilities (String)

Returns:



222
223
224
225
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 222

def list_templates(opts = {})
  data, _status_code, _headers = list_templates_with_http_info(opts)
  data
end

#list_templates_with_http_info(opts = {}) ⇒ Array<(ListTemplates200Response, Integer, Hash)>

List app templates Returns app templates. Optional query: capabilities&#x3D;queue,kv to filter by capability.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :capabilities (String)

Returns:

  • (Array<(ListTemplates200Response, Integer, Hash)>)

    ListTemplates200Response data, response status code and response headers



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/rocket_stack_sdk/api/resources_api.rb', line 232

def list_templates_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ResourcesApi.list_templates ...'
  end
  # resource path
  local_var_path = '/resources/templates'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'capabilities'] = opts[:'capabilities'] if !opts[:'capabilities'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListTemplates200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ResourcesApi.list_templates",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ResourcesApi#list_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end