Class: RocketStackSdk::UpdateFunctionRequest

Inherits:
ApiModelBase show all
Defined in:
lib/rocket_stack_sdk/models/update_function_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateFunctionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::UpdateFunctionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::UpdateFunctionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'memory_mb')
    self.memory_mb = attributes[:'memory_mb']
  end

  if attributes.key?(:'timeout_seconds')
    self.timeout_seconds = attributes[:'timeout_seconds']
  end

  if attributes.key?(:'env')
    if (value = attributes[:'env']).is_a?(Hash)
      self.env = value
    end
  end

  if attributes.key?(:'reserved_concurrency')
    self.reserved_concurrency = attributes[:'reserved_concurrency']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'is_public')
    self.is_public = attributes[:'is_public']
  end

  if attributes.key?(:'public_method')
    self.public_method = attributes[:'public_method']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 26

def description
  @description
end

#envObject

Returns the value of attribute env.



22
23
24
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 22

def env
  @env
end

#is_publicObject

Returns the value of attribute is_public.



28
29
30
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 28

def is_public
  @is_public
end

#memory_mbObject

Returns the value of attribute memory_mb.



18
19
20
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 18

def memory_mb
  @memory_mb
end

#public_methodObject

Returns the value of attribute public_method.



30
31
32
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 30

def public_method
  @public_method
end

#reserved_concurrencyObject

Returns the value of attribute reserved_concurrency.



24
25
26
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 24

def reserved_concurrency
  @reserved_concurrency
end

#timeout_secondsObject

Returns the value of attribute timeout_seconds.



20
21
22
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 20

def timeout_seconds
  @timeout_seconds
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 55

def self.attribute_map
  {
    :'memory_mb' => :'memoryMb',
    :'timeout_seconds' => :'timeoutSeconds',
    :'env' => :'env',
    :'reserved_concurrency' => :'reservedConcurrency',
    :'description' => :'description',
    :'is_public' => :'isPublic',
    :'public_method' => :'publicMethod'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 299

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 91

def self.openapi_nullable
  Set.new([
    :'reserved_concurrency',
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 78

def self.openapi_types
  {
    :'memory_mb' => :'Float',
    :'timeout_seconds' => :'Float',
    :'env' => :'Hash<String, String>',
    :'reserved_concurrency' => :'Float',
    :'description' => :'String',
    :'is_public' => :'Boolean',
    :'public_method' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



272
273
274
275
276
277
278
279
280
281
282
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 272

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      memory_mb == o.memory_mb &&
      timeout_seconds == o.timeout_seconds &&
      env == o.env &&
      reserved_concurrency == o.reserved_concurrency &&
      description == o.description &&
      is_public == o.is_public &&
      public_method == o.public_method
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 286

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



292
293
294
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 292

def hash
  [memory_mb, timeout_seconds, env, reserved_concurrency, description, is_public, public_method].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@memory_mb.nil? && @memory_mb > 10240
    invalid_properties.push('invalid value for "memory_mb", must be smaller than or equal to 10240.')
  end

  if !@memory_mb.nil? && @memory_mb < 128
    invalid_properties.push('invalid value for "memory_mb", must be greater than or equal to 128.')
  end

  if !@timeout_seconds.nil? && @timeout_seconds > 60
    invalid_properties.push('invalid value for "timeout_seconds", must be smaller than or equal to 60.')
  end

  if !@timeout_seconds.nil? && @timeout_seconds < 1
    invalid_properties.push('invalid value for "timeout_seconds", must be greater than or equal to 1.')
  end

  if !@reserved_concurrency.nil? && @reserved_concurrency > 100
    invalid_properties.push('invalid value for "reserved_concurrency", must be smaller than or equal to 100.')
  end

  if !@reserved_concurrency.nil? && @reserved_concurrency < 0
    invalid_properties.push('invalid value for "reserved_concurrency", must be greater than or equal to 0.')
  end

  if !@description.nil? && @description.to_s.length > 256
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 256.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/rocket_stack_sdk/models/update_function_request.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@memory_mb.nil? && @memory_mb > 10240
  return false if !@memory_mb.nil? && @memory_mb < 128
  return false if !@timeout_seconds.nil? && @timeout_seconds > 60
  return false if !@timeout_seconds.nil? && @timeout_seconds < 1
  return false if !@reserved_concurrency.nil? && @reserved_concurrency > 100
  return false if !@reserved_concurrency.nil? && @reserved_concurrency < 0
  return false if !@description.nil? && @description.to_s.length > 256
  public_method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PATCH", "DELETE"])
  return false unless public_method_validator.valid?(@public_method)
  true
end