Class: RocketStackSdk::UpdateQueueRequest

Inherits:
ApiModelBase show all
Defined in:
lib/rocket_stack_sdk/models/update_queue_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateQueueRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::UpdateQueueRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::UpdateQueueRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'visibility_timeout_seconds')
    self.visibility_timeout_seconds = attributes[:'visibility_timeout_seconds']
  end

  if attributes.key?(:'retention_seconds')
    self.retention_seconds = attributes[:'retention_seconds']
  end

  if attributes.key?(:'max_receive_count')
    self.max_receive_count = attributes[:'max_receive_count']
  end

  if attributes.key?(:'delivery_target')
    self.delivery_target = attributes[:'delivery_target']
  end
end

Instance Attribute Details

#delivery_targetObject

Returns the value of attribute delivery_target.



24
25
26
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 24

def delivery_target
  @delivery_target
end

#max_receive_countObject

Returns the value of attribute max_receive_count.



22
23
24
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 22

def max_receive_count
  @max_receive_count
end

#retention_secondsObject

Returns the value of attribute retention_seconds.



20
21
22
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 20

def retention_seconds
  @retention_seconds
end

#visibility_timeout_secondsObject

Returns the value of attribute visibility_timeout_seconds.



18
19
20
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 18

def visibility_timeout_seconds
  @visibility_timeout_seconds
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 27

def self.attribute_map
  {
    :'visibility_timeout_seconds' => :'visibilityTimeoutSeconds',
    :'retention_seconds' => :'retentionSeconds',
    :'max_receive_count' => :'maxReceiveCount',
    :'delivery_target' => :'deliveryTarget'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 220

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 47

def self.openapi_types
  {
    :'visibility_timeout_seconds' => :'Float',
    :'retention_seconds' => :'Float',
    :'max_receive_count' => :'Float',
    :'delivery_target' => :'CreateQueueRequestDeliveryTarget'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      visibility_timeout_seconds == o.visibility_timeout_seconds &&
      retention_seconds == o.retention_seconds &&
      max_receive_count == o.max_receive_count &&
      delivery_target == o.delivery_target
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


207
208
209
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 207

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



213
214
215
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 213

def hash
  [visibility_timeout_seconds, retention_seconds, max_receive_count, delivery_target].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds > 43200
    invalid_properties.push('invalid value for "visibility_timeout_seconds", must be smaller than or equal to 43200.')
  end

  if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds < 0
    invalid_properties.push('invalid value for "visibility_timeout_seconds", must be greater than or equal to 0.')
  end

  if !@retention_seconds.nil? && @retention_seconds > 1209600
    invalid_properties.push('invalid value for "retention_seconds", must be smaller than or equal to 1209600.')
  end

  if !@retention_seconds.nil? && @retention_seconds < 60
    invalid_properties.push('invalid value for "retention_seconds", must be greater than or equal to 60.')
  end

  if !@max_receive_count.nil? && @max_receive_count > 100
    invalid_properties.push('invalid value for "max_receive_count", must be smaller than or equal to 100.')
  end

  if !@max_receive_count.nil? && @max_receive_count < 1
    invalid_properties.push('invalid value for "max_receive_count", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
134
135
136
137
138
# File 'lib/rocket_stack_sdk/models/update_queue_request.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds > 43200
  return false if !@visibility_timeout_seconds.nil? && @visibility_timeout_seconds < 0
  return false if !@retention_seconds.nil? && @retention_seconds > 1209600
  return false if !@retention_seconds.nil? && @retention_seconds < 60
  return false if !@max_receive_count.nil? && @max_receive_count > 100
  return false if !@max_receive_count.nil? && @max_receive_count < 1
  true
end