Class: RocketStackSdk::CreateCronJobRequestDeliveryTarget
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::CreateCronJobRequestDeliveryTarget
- Defined in:
- lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#function_id ⇒ Object
Returns the value of attribute function_id.
-
#max_in_flight ⇒ Object
Returns the value of attribute max_in_flight.
-
#max_per_second ⇒ Object
Returns the value of attribute max_per_second.
-
#retryable_status_codes ⇒ Object
Returns the value of attribute retryable_status_codes.
-
#timeout_seconds ⇒ Object
Returns the value of attribute timeout_seconds.
-
#type ⇒ Object
Returns the value of attribute type.
-
#webhook_headers ⇒ Object
Returns the value of attribute webhook_headers.
-
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCronJobRequestDeliveryTarget
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCronJobRequestDeliveryTarget
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::CreateCronJobRequestDeliveryTarget` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::CreateCronJobRequestDeliveryTarget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'function_id') self.function_id = attributes[:'function_id'] end if attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] end if attributes.key?(:'webhook_headers') if (value = attributes[:'webhook_headers']).is_a?(Hash) self.webhook_headers = value end end if attributes.key?(:'timeout_seconds') self.timeout_seconds = attributes[:'timeout_seconds'] else self.timeout_seconds = 10 end if attributes.key?(:'max_in_flight') self.max_in_flight = attributes[:'max_in_flight'] else self.max_in_flight = 5 end if attributes.key?(:'max_per_second') self.max_per_second = attributes[:'max_per_second'] end if attributes.key?(:'retryable_status_codes') if (value = attributes[:'retryable_status_codes']).is_a?(Array) self.retryable_status_codes = value end end end |
Instance Attribute Details
#function_id ⇒ Object
Returns the value of attribute function_id.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 20 def function_id @function_id end |
#max_in_flight ⇒ Object
Returns the value of attribute max_in_flight.
28 29 30 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 28 def max_in_flight @max_in_flight end |
#max_per_second ⇒ Object
Returns the value of attribute max_per_second.
30 31 32 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 30 def max_per_second @max_per_second end |
#retryable_status_codes ⇒ Object
Returns the value of attribute retryable_status_codes.
32 33 34 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 32 def retryable_status_codes @retryable_status_codes end |
#timeout_seconds ⇒ Object
Returns the value of attribute timeout_seconds.
26 27 28 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 26 def timeout_seconds @timeout_seconds end |
#type ⇒ Object
Returns the value of attribute type.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 18 def type @type end |
#webhook_headers ⇒ Object
Returns the value of attribute webhook_headers.
24 25 26 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 24 def webhook_headers @webhook_headers end |
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
22 23 24 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 22 def webhook_url @webhook_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 57 def self.attribute_map { :'type' => :'type', :'function_id' => :'functionId', :'webhook_url' => :'webhookUrl', :'webhook_headers' => :'webhookHeaders', :'timeout_seconds' => :'timeoutSeconds', :'max_in_flight' => :'maxInFlight', :'max_per_second' => :'maxPerSecond', :'retryable_status_codes' => :'retryableStatusCodes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 305 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 81 def self.openapi_types { :'type' => :'String', :'function_id' => :'String', :'webhook_url' => :'String', :'webhook_headers' => :'Hash<String, String>', :'timeout_seconds' => :'Float', :'max_in_flight' => :'Float', :'max_per_second' => :'Float', :'retryable_status_codes' => :'Array<Float>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 277 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && function_id == o.function_id && webhook_url == o.webhook_url && webhook_headers == o.webhook_headers && timeout_seconds == o.timeout_seconds && max_in_flight == o.max_in_flight && max_per_second == o.max_per_second && retryable_status_codes == o.retryable_status_codes end |
#eql?(o) ⇒ Boolean
292 293 294 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 292 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
298 299 300 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 298 def hash [type, function_id, webhook_url, webhook_headers, timeout_seconds, max_in_flight, max_per_second, retryable_status_codes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if !@timeout_seconds.nil? && @timeout_seconds > 30 invalid_properties.push('invalid value for "timeout_seconds", must be smaller than or equal to 30.') end if !@timeout_seconds.nil? && @timeout_seconds < 1 invalid_properties.push('invalid value for "timeout_seconds", must be greater than or equal to 1.') end if !@max_in_flight.nil? && @max_in_flight > 50 invalid_properties.push('invalid value for "max_in_flight", must be smaller than or equal to 50.') end if !@max_in_flight.nil? && @max_in_flight < 1 invalid_properties.push('invalid value for "max_in_flight", must be greater than or equal to 1.') end if !@max_per_second.nil? && @max_per_second > 200 invalid_properties.push('invalid value for "max_per_second", must be smaller than or equal to 200.') end if !@max_per_second.nil? && @max_per_second < 1 invalid_properties.push('invalid value for "max_per_second", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 327 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/rocket_stack_sdk/models/create_cron_job_request_delivery_target.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["function", "webhook"]) return false unless type_validator.valid?(@type) return false if !@timeout_seconds.nil? && @timeout_seconds > 30 return false if !@timeout_seconds.nil? && @timeout_seconds < 1 return false if !@max_in_flight.nil? && @max_in_flight > 50 return false if !@max_in_flight.nil? && @max_in_flight < 1 return false if !@max_per_second.nil? && @max_per_second > 200 return false if !@max_per_second.nil? && @max_per_second < 1 true end |