Class: RocketStackSdk::GetMessageStatus200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::GetMessageStatus200ResponseData
- Defined in:
- lib/rocket_stack_sdk/models/get_message_status200_response_data.rb
Instance Attribute Summary collapse
-
#attempts ⇒ Object
Returns the value of attribute attempts.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#last_error ⇒ Object
Returns the value of attribute last_error.
-
#message_id ⇒ Object
Returns the value of attribute message_id.
-
#payload_size_bytes ⇒ Object
Returns the value of attribute payload_size_bytes.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetMessageStatus200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetMessageStatus200ResponseData
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::GetMessageStatus200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::GetMessageStatus200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message_id') self. = attributes[:'message_id'] else self. = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'attempts') self.attempts = attributes[:'attempts'] else self.attempts = nil end if attributes.key?(:'last_error') self.last_error = attributes[:'last_error'] end if attributes.key?(:'payload_size_bytes') self.payload_size_bytes = attributes[:'payload_size_bytes'] else self.payload_size_bytes = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#attempts ⇒ Object
Returns the value of attribute attempts.
22 23 24 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 22 def attempts @attempts end |
#created_at ⇒ Object
Returns the value of attribute created_at.
28 29 30 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 28 def created_at @created_at end |
#last_error ⇒ Object
Returns the value of attribute last_error.
24 25 26 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 24 def last_error @last_error end |
#message_id ⇒ Object
Returns the value of attribute message_id.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 18 def end |
#payload_size_bytes ⇒ Object
Returns the value of attribute payload_size_bytes.
26 27 28 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 26 def payload_size_bytes @payload_size_bytes end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 20 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
30 31 32 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 30 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 33 def self.attribute_map { :'message_id' => :'messageId', :'status' => :'status', :'attempts' => :'attempts', :'last_error' => :'lastError', :'payload_size_bytes' => :'payloadSizeBytes', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 265 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 56 def self.openapi_types { :'message_id' => :'String', :'status' => :'String', :'attempts' => :'Float', :'last_error' => :'String', :'payload_size_bytes' => :'Float', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && status == o.status && attempts == o.attempts && last_error == o.last_error && payload_size_bytes == o.payload_size_bytes && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
252 253 254 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 252 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 258 def hash [, status, attempts, last_error, payload_size_bytes, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if .nil? invalid_properties.push('invalid value for "message_id", message_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @attempts.nil? invalid_properties.push('invalid value for "attempts", attempts cannot be nil.') end if @payload_size_bytes.nil? invalid_properties.push('invalid value for "payload_size_bytes", payload_size_bytes cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 173 174 |
# File 'lib/rocket_stack_sdk/models/get_message_status200_response_data.rb', line 165 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if .nil? return false if @status.nil? return false if @attempts.nil? return false if @payload_size_bytes.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |