Class: RocketStackSdk::KvApi

Inherits:
Object
  • Object
show all
Defined in:
lib/rocket_stack_sdk/api/kv_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ KvApi

Returns a new instance of KvApi.



19
20
21
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_kv_item(key, opts = {}) ⇒ DeleteKvItem200Response

Delete a KV item Deletes a key-value item by key (single path segment).

Parameters:

  • (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 27

def delete_kv_item(key, opts = {})
  data, _status_code, _headers = delete_kv_item_with_http_info(key, opts)
  data
end

#delete_kv_item_with_http_info(key, opts = {}) ⇒ Array<(DeleteKvItem200Response, Integer, Hash)>

Delete a KV item Deletes a key-value item by key (single path segment).

Parameters:

  • (defaults to: {})

    the optional parameters

Returns:

  • DeleteKvItem200Response data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 37

def delete_kv_item_with_http_info(key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KvApi.delete_kv_item ...'
  end
  # verify the required parameter 'key' is set
  if @api_client.config.client_side_validation && key.nil?
    fail ArgumentError, "Missing the required parameter 'key' when calling KvApi.delete_kv_item"
  end
  if @api_client.config.client_side_validation && key.to_s.length < 1
    fail ArgumentError, 'invalid value for "key" when calling KvApi.delete_kv_item, the character length must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/kv/items/{key}'.sub('{' + 'key' + '}', CGI.escape(key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteKvItem200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"KvApi.delete_kv_item",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KvApi#delete_kv_item\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_kv_item(key, opts = {}) ⇒ GetKvItem200Response

Get a KV item by key Retrieves a single key-value item. The key is specified as a single path segment (slashes not supported in path).

Parameters:

  • (defaults to: {})

    the optional parameters

Returns:



94
95
96
97
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 94

def get_kv_item(key, opts = {})
  data, _status_code, _headers = get_kv_item_with_http_info(key, opts)
  data
end

#get_kv_item_with_http_info(key, opts = {}) ⇒ Array<(GetKvItem200Response, Integer, Hash)>

Get a KV item by key Retrieves a single key-value item. The key is specified as a single path segment (slashes not supported in path).

Parameters:

  • (defaults to: {})

    the optional parameters

Returns:

  • GetKvItem200Response data, response status code and response headers



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 104

def get_kv_item_with_http_info(key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KvApi.get_kv_item ...'
  end
  # verify the required parameter 'key' is set
  if @api_client.config.client_side_validation && key.nil?
    fail ArgumentError, "Missing the required parameter 'key' when calling KvApi.get_kv_item"
  end
  if @api_client.config.client_side_validation && key.to_s.length < 1
    fail ArgumentError, 'invalid value for "key" when calling KvApi.get_kv_item, the character length must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/kv/items/{key}'.sub('{' + 'key' + '}', CGI.escape(key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetKvItem200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"KvApi.get_kv_item",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KvApi#get_kv_item\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_kv_items(opts = {}) ⇒ ListKvItems200Response

List KV items Returns a paginated list of KV items, optionally filtered by prefix.

Parameters:

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :prefix (String)
  • :limit (Integer) — default: default to 50
  • :cursor (String)

Returns:



163
164
165
166
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 163

def list_kv_items(opts = {})
  data, _status_code, _headers = list_kv_items_with_http_info(opts)
  data
end

#list_kv_items_with_http_info(opts = {}) ⇒ Array<(ListKvItems200Response, Integer, Hash)>

List KV items Returns a paginated list of KV items, optionally filtered by prefix.

Parameters:

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :prefix (String)
  • :limit (Integer) — default: default to 50
  • :cursor (String)

Returns:

  • ListKvItems200Response data, response status code and response headers



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 175

def list_kv_items_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KvApi.list_kv_items ...'
  end
  if @api_client.config.client_side_validation && !opts[:'prefix'].nil? && opts[:'prefix'].to_s.length > 512
    fail ArgumentError, 'invalid value for "opts[:"prefix"]" when calling KvApi.list_kv_items, the character length must be smaller than or equal to 512.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KvApi.list_kv_items, must be smaller than or equal to 200.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KvApi.list_kv_items, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/kv/items'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'prefix'] = opts[:'prefix'] if !opts[:'prefix'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListKvItems200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"KvApi.list_kv_items",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KvApi#list_kv_items\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#put_kv_item(key, opts = {}) ⇒ PutKvItem200Response

Create or update a KV item Creates or updates a key-value item. Supports TTL and conditional writes via ifVersion. Key is a single path segment.

Parameters:

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



240
241
242
243
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 240

def put_kv_item(key, opts = {})
  data, _status_code, _headers = put_kv_item_with_http_info(key, opts)
  data
end

#put_kv_item_with_http_info(key, opts = {}) ⇒ Array<(PutKvItem200Response, Integer, Hash)>

Create or update a KV item Creates or updates a key-value item. Supports TTL and conditional writes via ifVersion. Key is a single path segment.

Parameters:

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • PutKvItem200Response data, response status code and response headers



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/rocket_stack_sdk/api/kv_api.rb', line 251

def put_kv_item_with_http_info(key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KvApi.put_kv_item ...'
  end
  # verify the required parameter 'key' is set
  if @api_client.config.client_side_validation && key.nil?
    fail ArgumentError, "Missing the required parameter 'key' when calling KvApi.put_kv_item"
  end
  if @api_client.config.client_side_validation && key.to_s.length < 1
    fail ArgumentError, 'invalid value for "key" when calling KvApi.put_kv_item, the character length must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/kv/items/{key}'.sub('{' + 'key' + '}', CGI.escape(key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'put_kv_item_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'PutKvItem200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"KvApi.put_kv_item",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KvApi#put_kv_item\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end