Class: RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpec
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpec
- Defined in:
- lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#code ⇒ Object
Returns the value of attribute code.
-
#description ⇒ Object
Returns the value of attribute description.
-
#env ⇒ Object
Returns the value of attribute env.
-
#handler ⇒ Object
Returns the value of attribute handler.
-
#is_public ⇒ Object
Returns the value of attribute is_public.
-
#memory_mb ⇒ Object
Returns the value of attribute memory_mb.
-
#public_method ⇒ Object
Returns the value of attribute public_method.
-
#reserved_concurrency ⇒ Object
Returns the value of attribute reserved_concurrency.
-
#runtime ⇒ Object
Returns the value of attribute runtime.
-
#timeout_seconds ⇒ Object
Returns the value of attribute timeout_seconds.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListFunctions200ResponseDataItemsInnerDesiredSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListFunctions200ResponseDataItemsInnerDesiredSpec
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListFunctions200ResponseDataItemsInnerDesiredSpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'runtime') self.runtime = attributes[:'runtime'] else self.runtime = nil end if attributes.key?(:'handler') self.handler = attributes[:'handler'] else self.handler = nil end if attributes.key?(:'memory_mb') self.memory_mb = attributes[:'memory_mb'] else self.memory_mb = nil end if attributes.key?(:'timeout_seconds') self.timeout_seconds = attributes[:'timeout_seconds'] else self.timeout_seconds = nil end if attributes.key?(:'reserved_concurrency') self.reserved_concurrency = attributes[:'reserved_concurrency'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'env') if (value = attributes[:'env']).is_a?(Hash) self.env = value end end if attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] else self.is_public = nil end if attributes.key?(:'public_method') self.public_method = attributes[:'public_method'] end if attributes.key?(:'code') self.code = attributes[:'code'] end end |
Instance Attribute Details
#code ⇒ Object
Returns the value of attribute code.
36 37 38 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 36 def code @code end |
#description ⇒ Object
Returns the value of attribute description.
28 29 30 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 28 def description @description end |
#env ⇒ Object
Returns the value of attribute env.
30 31 32 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 30 def env @env end |
#handler ⇒ Object
Returns the value of attribute handler.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 20 def handler @handler end |
#is_public ⇒ Object
Returns the value of attribute is_public.
32 33 34 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 32 def is_public @is_public end |
#memory_mb ⇒ Object
Returns the value of attribute memory_mb.
22 23 24 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 22 def memory_mb @memory_mb end |
#public_method ⇒ Object
Returns the value of attribute public_method.
34 35 36 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 34 def public_method @public_method end |
#reserved_concurrency ⇒ Object
Returns the value of attribute reserved_concurrency.
26 27 28 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 26 def reserved_concurrency @reserved_concurrency end |
#runtime ⇒ Object
Returns the value of attribute runtime.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 18 def runtime @runtime end |
#timeout_seconds ⇒ Object
Returns the value of attribute timeout_seconds.
24 25 26 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 24 def timeout_seconds @timeout_seconds end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 61 def self.attribute_map { :'runtime' => :'runtime', :'handler' => :'handler', :'memory_mb' => :'memoryMb', :'timeout_seconds' => :'timeoutSeconds', :'reserved_concurrency' => :'reservedConcurrency', :'description' => :'description', :'env' => :'env', :'is_public' => :'isPublic', :'public_method' => :'publicMethod', :'code' => :'code' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 314 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 107 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 103 def self.openapi_nullable Set.new([ :'reserved_concurrency', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 87 def self.openapi_types { :'runtime' => :'String', :'handler' => :'String', :'memory_mb' => :'Float', :'timeout_seconds' => :'Float', :'reserved_concurrency' => :'Float', :'description' => :'String', :'env' => :'Hash<String, String>', :'is_public' => :'Boolean', :'public_method' => :'String', :'code' => :'ListFunctions200ResponseDataItemsInnerDesiredSpecCode' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 284 def ==(o) return true if self.equal?(o) self.class == o.class && runtime == o.runtime && handler == o.handler && memory_mb == o.memory_mb && timeout_seconds == o.timeout_seconds && reserved_concurrency == o.reserved_concurrency && description == o.description && env == o.env && is_public == o.is_public && public_method == o.public_method && code == o.code end |
#eql?(o) ⇒ Boolean
301 302 303 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 301 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
307 308 309 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 307 def hash [runtime, handler, memory_mb, timeout_seconds, reserved_concurrency, description, env, is_public, public_method, code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 180 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @runtime.nil? invalid_properties.push('invalid value for "runtime", runtime cannot be nil.') end if @handler.nil? invalid_properties.push('invalid value for "handler", handler cannot be nil.') end if @memory_mb.nil? invalid_properties.push('invalid value for "memory_mb", memory_mb cannot be nil.') end if @timeout_seconds.nil? invalid_properties.push('invalid value for "timeout_seconds", timeout_seconds cannot be nil.') end if @is_public.nil? invalid_properties.push('invalid value for "is_public", is_public cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 336 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/rocket_stack_sdk/models/list_functions200_response_data_items_inner_desired_spec.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @runtime.nil? runtime_validator = EnumAttributeValidator.new('String', ["nodejs20.x", "python3.12"]) return false unless runtime_validator.valid?(@runtime) return false if @handler.nil? return false if @memory_mb.nil? return false if @timeout_seconds.nil? return false if @is_public.nil? public_method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PATCH", "DELETE"]) return false unless public_method_validator.valid?(@public_method) true end |