Class: RocketStackSdk::ListQueues200ResponseDataItemsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- RocketStackSdk::ListQueues200ResponseDataItemsInner
- Defined in:
- lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#delivery_target ⇒ Object
Returns the value of attribute delivery_target.
-
#id ⇒ Object
Returns the value of attribute id.
-
#max_receive_count ⇒ Object
Returns the value of attribute max_receive_count.
-
#name ⇒ Object
Returns the value of attribute name.
-
#resource_key ⇒ Object
Returns the value of attribute resource_key.
-
#retention_seconds ⇒ Object
Returns the value of attribute retention_seconds.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#visibility_timeout_seconds ⇒ Object
Returns the value of attribute visibility_timeout_seconds.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListQueues200ResponseDataItemsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListQueues200ResponseDataItemsInner
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `RocketStackSdk::ListQueues200ResponseDataItemsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `RocketStackSdk::ListQueues200ResponseDataItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'resource_key') self.resource_key = attributes[:'resource_key'] else self.resource_key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'visibility_timeout_seconds') self.visibility_timeout_seconds = attributes[:'visibility_timeout_seconds'] else self.visibility_timeout_seconds = nil end if attributes.key?(:'retention_seconds') self.retention_seconds = attributes[:'retention_seconds'] else self.retention_seconds = nil end if attributes.key?(:'max_receive_count') self.max_receive_count = attributes[:'max_receive_count'] else self.max_receive_count = nil end if attributes.key?(:'delivery_target') self.delivery_target = attributes[:'delivery_target'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 34 def created_at @created_at end |
#delivery_target ⇒ Object
Returns the value of attribute delivery_target.
32 33 34 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 32 def delivery_target @delivery_target end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 18 def id @id end |
#max_receive_count ⇒ Object
Returns the value of attribute max_receive_count.
30 31 32 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 30 def max_receive_count @max_receive_count end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 22 def name @name end |
#resource_key ⇒ Object
Returns the value of attribute resource_key.
20 21 22 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 20 def resource_key @resource_key end |
#retention_seconds ⇒ Object
Returns the value of attribute retention_seconds.
28 29 30 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 28 def retention_seconds @retention_seconds end |
#status ⇒ Object
Returns the value of attribute status.
24 25 26 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 24 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 36 def updated_at @updated_at end |
#visibility_timeout_seconds ⇒ Object
Returns the value of attribute visibility_timeout_seconds.
26 27 28 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 26 def visibility_timeout_seconds @visibility_timeout_seconds end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 39 def self.attribute_map { :'id' => :'id', :'resource_key' => :'resourceKey', :'name' => :'name', :'status' => :'status', :'visibility_timeout_seconds' => :'visibilityTimeoutSeconds', :'retention_seconds' => :'retentionSeconds', :'max_receive_count' => :'maxReceiveCount', :'delivery_target' => :'deliveryTarget', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 343 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 65 def self.openapi_types { :'id' => :'String', :'resource_key' => :'String', :'name' => :'String', :'status' => :'String', :'visibility_timeout_seconds' => :'Float', :'retention_seconds' => :'Float', :'max_receive_count' => :'Float', :'delivery_target' => :'ListQueues200ResponseDataItemsInnerDeliveryTarget', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 313 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && resource_key == o.resource_key && name == o.name && status == o.status && visibility_timeout_seconds == o.visibility_timeout_seconds && retention_seconds == o.retention_seconds && max_receive_count == o.max_receive_count && delivery_target == o.delivery_target && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
330 331 332 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 330 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
336 337 338 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 336 def hash [id, resource_key, name, status, visibility_timeout_seconds, retention_seconds, max_receive_count, delivery_target, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @resource_key.nil? invalid_properties.push('invalid value for "resource_key", resource_key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @visibility_timeout_seconds.nil? invalid_properties.push('invalid value for "visibility_timeout_seconds", visibility_timeout_seconds cannot be nil.') end if @retention_seconds.nil? invalid_properties.push('invalid value for "retention_seconds", retention_seconds cannot be nil.') end if @max_receive_count.nil? invalid_properties.push('invalid value for "max_receive_count", max_receive_count cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 365 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/rocket_stack_sdk/models/list_queues200_response_data_items_inner.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @resource_key.nil? return false if @name.nil? return false if @status.nil? return false if @visibility_timeout_seconds.nil? return false if @retention_seconds.nil? return false if @max_receive_count.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |