Class: RocketStackSdk::StorageApi
- Inherits:
-
Object
- Object
- RocketStackSdk::StorageApi
- Defined in:
- lib/rocket_stack_sdk/api/storage_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_download_url(create_download_url_request, opts = {}) ⇒ CreateDownloadUrl200Response
Create a presigned download URL Generates a presigned S3 URL for downloading an object.
-
#create_download_url_with_http_info(create_download_url_request, opts = {}) ⇒ Array<(CreateDownloadUrl200Response, Integer, Hash)>
Create a presigned download URL Generates a presigned S3 URL for downloading an object.
-
#delete_storage_object(path, opts = {}) ⇒ DeleteKvItem200Response
Delete a storage object Deletes an object by path.
-
#delete_storage_object_with_http_info(path, opts = {}) ⇒ Array<(DeleteKvItem200Response, Integer, Hash)>
Delete a storage object Deletes an object by path.
-
#finalize_upload(finalize_upload_request, opts = {}) ⇒ FinalizeUpload200Response
Finalize an upload Verifies an uploaded object exists and returns its metadata.
-
#finalize_upload_with_http_info(finalize_upload_request, opts = {}) ⇒ Array<(FinalizeUpload200Response, Integer, Hash)>
Finalize an upload Verifies an uploaded object exists and returns its metadata.
-
#get_public_object(tenant_id, wildcard, opts = {}) ⇒ File
Get a public object Returns the object body for a public object.
-
#get_public_object_with_http_info(tenant_id, wildcard, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get a public object Returns the object body for a public object.
-
#initialize(api_client = ApiClient.default) ⇒ StorageApi
constructor
A new instance of StorageApi.
-
#list_storage_objects(opts = {}) ⇒ ListStorageObjects200Response
List storage objects Returns a paginated list of objects in storage, optionally filtered by prefix.
-
#list_storage_objects_with_http_info(opts = {}) ⇒ Array<(ListStorageObjects200Response, Integer, Hash)>
List storage objects Returns a paginated list of objects in storage, optionally filtered by prefix.
-
#upload_object(file, path, opts = {}) ⇒ UploadObject201Response
Upload an object Upload a file directly to storage via multipart form data.
-
#upload_object_with_http_info(file, path, opts = {}) ⇒ Array<(UploadObject201Response, Integer, Hash)>
Upload an object Upload a file directly to storage via multipart form data.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ StorageApi
Returns a new instance of StorageApi.
19 20 21 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_download_url(create_download_url_request, opts = {}) ⇒ CreateDownloadUrl200Response
Create a presigned download URL Generates a presigned S3 URL for downloading an object.
27 28 29 30 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 27 def create_download_url(create_download_url_request, opts = {}) data, _status_code, _headers = create_download_url_with_http_info(create_download_url_request, opts) data end |
#create_download_url_with_http_info(create_download_url_request, opts = {}) ⇒ Array<(CreateDownloadUrl200Response, Integer, Hash)>
Create a presigned download URL Generates a presigned S3 URL for downloading an object.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 37 def create_download_url_with_http_info(create_download_url_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageApi.create_download_url ...' end # verify the required parameter 'create_download_url_request' is set if @api_client.config.client_side_validation && create_download_url_request.nil? fail ArgumentError, "Missing the required parameter 'create_download_url_request' when calling StorageApi.create_download_url" end # resource path local_var_path = '/storage/download-url' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_download_url_request) # return_type return_type = opts[:debug_return_type] || 'CreateDownloadUrl200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"StorageApi.create_download_url", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageApi#create_download_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_storage_object(path, opts = {}) ⇒ DeleteKvItem200Response
Delete a storage object Deletes an object by path.
96 97 98 99 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 96 def delete_storage_object(path, opts = {}) data, _status_code, _headers = delete_storage_object_with_http_info(path, opts) data end |
#delete_storage_object_with_http_info(path, opts = {}) ⇒ Array<(DeleteKvItem200Response, Integer, Hash)>
Delete a storage object Deletes an object by path.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 107 def delete_storage_object_with_http_info(path, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageApi.delete_storage_object ...' end # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? fail ArgumentError, "Missing the required parameter 'path' when calling StorageApi.delete_storage_object" end if @api_client.config.client_side_validation && path.to_s.length > 1024 fail ArgumentError, 'invalid value for "path" when calling StorageApi.delete_storage_object, the character length must be smaller than or equal to 1024.' end if @api_client.config.client_side_validation && path.to_s.length < 1 fail ArgumentError, 'invalid value for "path" when calling StorageApi.delete_storage_object, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/storage/objects' # query parameters query_params = opts[:query_params] || {} query_params[:'path'] = path query_params[:'public'] = opts[:'public'] if !opts[:'public'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteKvItem200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"StorageApi.delete_storage_object", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageApi#delete_storage_object\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#finalize_upload(finalize_upload_request, opts = {}) ⇒ FinalizeUpload200Response
Finalize an upload Verifies an uploaded object exists and returns its metadata.
170 171 172 173 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 170 def finalize_upload(finalize_upload_request, opts = {}) data, _status_code, _headers = finalize_upload_with_http_info(finalize_upload_request, opts) data end |
#finalize_upload_with_http_info(finalize_upload_request, opts = {}) ⇒ Array<(FinalizeUpload200Response, Integer, Hash)>
Finalize an upload Verifies an uploaded object exists and returns its metadata.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 180 def finalize_upload_with_http_info(finalize_upload_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageApi.finalize_upload ...' end # verify the required parameter 'finalize_upload_request' is set if @api_client.config.client_side_validation && finalize_upload_request.nil? fail ArgumentError, "Missing the required parameter 'finalize_upload_request' when calling StorageApi.finalize_upload" end # resource path local_var_path = '/storage/finalize' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(finalize_upload_request) # return_type return_type = opts[:debug_return_type] || 'FinalizeUpload200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"StorageApi.finalize_upload", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageApi#finalize_upload\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_public_object(tenant_id, wildcard, opts = {}) ⇒ File
Get a public object Returns the object body for a public object. No authentication required. This is the stable URL for objects uploaded with public=true.
239 240 241 242 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 239 def get_public_object(tenant_id, wildcard, opts = {}) data, _status_code, _headers = get_public_object_with_http_info(tenant_id, wildcard, opts) data end |
#get_public_object_with_http_info(tenant_id, wildcard, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get a public object Returns the object body for a public object. No authentication required. This is the stable URL for objects uploaded with public=true.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 250 def get_public_object_with_http_info(tenant_id, wildcard, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageApi.get_public_object ...' end # verify the required parameter 'tenant_id' is set if @api_client.config.client_side_validation && tenant_id.nil? fail ArgumentError, "Missing the required parameter 'tenant_id' when calling StorageApi.get_public_object" end # verify the required parameter 'wildcard' is set if @api_client.config.client_side_validation && wildcard.nil? fail ArgumentError, "Missing the required parameter 'wildcard' when calling StorageApi.get_public_object" end # resource path local_var_path = '/storage/public/objects/{tenantId}/{wildcard}'.sub('{' + 'tenantId' + '}', CGI.escape(tenant_id.to_s)).sub('{' + 'wildcard' + '}', CGI.escape(wildcard.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream', 'application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'File' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"StorageApi.get_public_object", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageApi#get_public_object\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_storage_objects(opts = {}) ⇒ ListStorageObjects200Response
List storage objects Returns a paginated list of objects in storage, optionally filtered by prefix.
310 311 312 313 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 310 def list_storage_objects(opts = {}) data, _status_code, _headers = list_storage_objects_with_http_info(opts) data end |
#list_storage_objects_with_http_info(opts = {}) ⇒ Array<(ListStorageObjects200Response, Integer, Hash)>
List storage objects Returns a paginated list of objects in storage, optionally filtered by prefix.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 323 def list_storage_objects_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageApi.list_storage_objects ...' end if @api_client.config.client_side_validation && !opts[:'prefix'].nil? && opts[:'prefix'].to_s.length > 1024 fail ArgumentError, 'invalid value for "opts[:"prefix"]" when calling StorageApi.list_storage_objects, the character length must be smaller than or equal to 1024.' end allowable_values = ["all", "private", "public"] if @api_client.config.client_side_validation && opts[:'visibility'] && !allowable_values.include?(opts[:'visibility']) fail ArgumentError, "invalid value for \"visibility\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling StorageApi.list_storage_objects, must be smaller than or equal to 200.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling StorageApi.list_storage_objects, must be greater than or equal to 1.' end # resource path local_var_path = '/storage/objects' # query parameters query_params = opts[:query_params] || {} query_params[:'prefix'] = opts[:'prefix'] if !opts[:'prefix'].nil? query_params[:'visibility'] = opts[:'visibility'] if !opts[:'visibility'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListStorageObjects200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"StorageApi.list_storage_objects", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageApi#list_storage_objects\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#upload_object(file, path, opts = {}) ⇒ UploadObject201Response
Upload an object Upload a file directly to storage via multipart form data.
394 395 396 397 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 394 def upload_object(file, path, opts = {}) data, _status_code, _headers = upload_object_with_http_info(file, path, opts) data end |
#upload_object_with_http_info(file, path, opts = {}) ⇒ Array<(UploadObject201Response, Integer, Hash)>
Upload an object Upload a file directly to storage via multipart form data.
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/rocket_stack_sdk/api/storage_api.rb', line 406 def upload_object_with_http_info(file, path, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageApi.upload_object ...' end # verify the required parameter 'file' is set if @api_client.config.client_side_validation && file.nil? fail ArgumentError, "Missing the required parameter 'file' when calling StorageApi.upload_object" end # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? fail ArgumentError, "Missing the required parameter 'path' when calling StorageApi.upload_object" end if @api_client.config.client_side_validation && path.to_s.length > 1024 fail ArgumentError, 'invalid value for "path" when calling StorageApi.upload_object, the character length must be smaller than or equal to 1024.' end if @api_client.config.client_side_validation && path.to_s.length < 1 fail ArgumentError, 'invalid value for "path" when calling StorageApi.upload_object, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/storage/objects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['file'] = file form_params['path'] = path form_params['public'] = opts[:'public'] if !opts[:'public'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UploadObject201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"StorageApi.upload_object", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageApi#upload_object\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |